@@ -1,4 +1,3 @@
-#' @importFrom utils browseURL
 #' @export
 print.sjTable <- function(x, ...) {
   # check if we have filename specified
@@ -20,13 +19,12 @@ print.sjTable <- function(x, ...) {
   }
 }
 
-
 #' @importFrom knitr knit_print asis_output
 #' @export
-knit_print.sjTable <-  function(input, ...) {
-  x <- input$knitr
-  x <- replace_umlauts(x)
-  knitr::asis_output(x)
+knit_print.sjTable <-  function(x, ...) {
+  out <- x$knitr
+  out <- replace_umlauts(out)
+  knitr::asis_output(out)
   # knitr::asis_output(input$knitr)
 }
 
@@ -54,58 +52,58 @@ replace_umlauts <- function(x) {
 # knitr method for grpmean() ----
 
 #' @export
-knit_print.sjt_grpmean <-  function(input, ...) {
-  knitr::asis_output(pgrpmean(input, ...)$knitr)
+knit_print.sjt_grpmean <-  function(x, ...) {
+  knitr::asis_output(pgrpmean(x, ...)$knitr)
 }
 
 #' @export
-knit_print.sjt_grpmeans <-  function(input, ...) {
-  knitr::asis_output(pgrpmeans(input, ...)$knitr)
+knit_print.sjt_grpmeans <-  function(x, ...) {
+  knitr::asis_output(pgrpmeans(x, ...)$knitr)
 }
 
 
 # knitr method method for reliab_test() ----
 
 #' @export
-knit_print.sjt_reliab <-  function(input, ...) {
-  knitr::asis_output(preliab(input, ...)$knitr)
+knit_print.sjt_reliab <-  function(x, ...) {
+  knitr::asis_output(preliab(x, ...)$knitr)
 }
 
 
 # knitr method method for descr() ----
 
 #' @export
-knit_print.sjt_descr <-  function(input, ...) {
-  knitr::asis_output(pdescr(input, ...)$knitr)
+knit_print.sjt_descr <-  function(x, ...) {
+  knitr::asis_output(pdescr(x, ...)$knitr)
 }
 
 #' @export
-knit_print.sjt_grpdescr <-  function(input, ...) {
-  knitr::asis_output(pgdescr(input, ...)$knitr)
+knit_print.sjt_grpdescr <-  function(x, ...) {
+  knitr::asis_output(pgdescr(x, ...)$knitr)
 }
 
 
 # knitr method method for equi_test() ----
 
 #' @export
-knit_print.sjt_descr <-  function(input, ...) {
-  knitr::asis_output(pequi_test(input, ...)$knitr)
+knit_print.sjt_descr <-  function(x, ...) {
+  knitr::asis_output(pequi_test(x, ...)$knitr)
 }
 
 
 # knitr method for frq() ----
 
 #' @export
-knit_print.sjt_frq <-  function(input, ...) {
-  knitr::asis_output(pfrq(input, ...)$knitr)
+knit_print.sjt_frq <-  function(x, ...) {
+  knitr::asis_output(pfrq(x, ...)$knitr)
 }
 
 
 # knitr method for mwu() ----
 
 #' @export
-knit_print.sjt_mwu <-  function(input, ...) {
-  knitr::asis_output(pmwu(input, ...)$knitr)
+knit_print.sjt_mwu <-  function(x, ...) {
+  knitr::asis_output(pmwu(x, ...)$knitr)
 }
 
 
@@ -209,7 +207,6 @@ pgrpmean <- function(x, ...) {
 }
 
 
-#' @importFrom purrr map_chr
 pgrpmeans <- function(x, ...) {
   uv <- attr(x, "print", exact = TRUE) == "viewer"
   enc <- attr(x, "encoding", exact = TRUE)
@@ -221,7 +218,7 @@ pgrpmeans <- function(x, ...) {
     "Mean for %s by %s<br><span class=\"subtitle\">grouped by %s</span>",
     attr(.x, "dv.label", exact = TRUE),
     attr(.x, "grp.label", exact = TRUE),
-    gsub(pattern = "\n", replacement = "<br>", attr(.x, "group", exact = TRUE), fixed = T)
+    gsub(pattern = "\n", replacement = "<br>", attr(.x, "group", exact = TRUE), fixed = TRUE)
   ))
 
   footnotes <- purrr::map_chr(x, ~ sprintf(
@@ -343,13 +340,11 @@ preliab <- function(x, ...) {
 }
 
 
-#' @importFrom purrr map_if
-#' @importFrom sjmisc is_float
 pdescr <- function(x, ...) {
   digits <- 2
 
   # do we have digits argument?
-  add.args <- lapply(match.call(expand.dots = F)$`...`, function(x) x)
+  add.args <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
   if ("digits" %in% names(add.args)) digits <- eval(add.args[["digits"]])
 
   uv <- attr(x, "print", exact = TRUE) == "viewer"
@@ -373,9 +368,11 @@ pdescr <- function(x, ...) {
     "Skewness"
   )
 
+  present_columns <- c("var", "type", "label", "n", "NA.prc", "mean", "sd", "se", "md", "trimmed", "range", "skew")
+  chead <- chead[which(present_columns %in% colnames(x))]
 
-  x <- x %>%
-    purrr::map_if(sjmisc::is_float, ~ round(.x, digits)) %>%
+  x <- x |>
+    purrr::map_if(sjmisc::is_float, ~ round(.x, digits)) |>
     as.data.frame()
 
   tab_df(
@@ -402,18 +399,16 @@ pdescr <- function(x, ...) {
 }
 
 
-#' @importFrom purrr map_if map_chr map
-#' @importFrom sjmisc is_float
 pgdescr <- function(x, ...) {
   titles <- purrr::map_chr(x, ~ sprintf(
     "Basic descriptives<br><span class=\"subtitle\"><em>grouped by</em> %s</span>",
-    gsub(pattern = "\n", replacement = "<br>", attr(.x, "group", exact = TRUE), fixed = T)
+    gsub(pattern = "\n", replacement = "<br>", attr(.x, "group", exact = TRUE), fixed = TRUE)
   ))
 
   digits <- 2
 
   # do we have digits argument?
-  add.args <- lapply(match.call(expand.dots = F)$`...`, function(x) x)
+  add.args <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
   if ("digits" %in% names(add.args)) digits <- eval(add.args[["digits"]])
 
   uv <- attr(x, "print", exact = TRUE) == "viewer"
@@ -437,12 +432,12 @@ pgdescr <- function(x, ...) {
     "Skewness"
   )
 
-  x <- x %>%
+  x <- x |>
     purrr::map(~ purrr::map_if(
       .x,
       sjmisc::is_float,
       ~ round(.x, digits)
-    ) %>% as.data.frame())
+    ) |> as.data.frame())
 
   tab_dfs(
     x = x,
@@ -466,9 +461,6 @@ pgdescr <- function(x, ...) {
 }
 
 
-#' @importFrom purrr map_if map_chr map
-#' @importFrom dplyr n_distinct select
-#' @importFrom sjmisc is_empty
 pfrq <- function(x, ...) {
 
   uv <- attr(x, "print", exact = TRUE) == "viewer"
@@ -483,8 +475,8 @@ pfrq <- function(x, ...) {
     ret <- ""
 
     # get variable label
-    lab <- attr(i, "label", exact = T)
-    vt <- attr(i, "vartype", exact = T)
+    lab <- attr(i, "label", exact = TRUE)
+    vt <- attr(i, "vartype", exact = TRUE)
 
     # fix variable type string
     if (!sjmisc::is_empty(vt))
@@ -495,12 +487,12 @@ pfrq <- function(x, ...) {
     if (!is.null(lab)) ret <- sprintf("%s%s", lab, vt)
 
     # get grouping title label
-    grp <- attr(i, "group", exact = T)
+    grp <- attr(i, "group", exact = TRUE)
 
     if (!is.null(grp))
       ret <- sprintf("%s<br><span class=\"subtitle\"><em>grouped by:</em><br>%s</span>", ret, grp)
 
-    gsub(pattern = "\n", replacement = "<br>", x = ret, fixed = T)
+    gsub(pattern = "\n", replacement = "<br>", x = ret, fixed = TRUE)
   })
 
 
@@ -508,8 +500,8 @@ pfrq <- function(x, ...) {
     "total N=%i &middot; valid N=%i &middot; x&#772;=%.2f &middot; &sigma;=%.2f\n",
     sum(.x$frq, na.rm = TRUE),
     sum(.x$frq[1:(nrow(.x) - 1)], na.rm = TRUE),
-    attr(.x, "mean", exact = T),
-    attr(.x, "sd", exact = T)
+    attr(.x, "mean", exact = TRUE),
+    attr(.x, "sd", exact = TRUE)
   )
   )
 
@@ -547,7 +539,6 @@ pfrq <- function(x, ...) {
 }
 
 
-#' @importFrom stats na.omit kruskal.test
 pmwu <- function(x, ...) {
   fn <- NULL
 
