@@ -33,6 +33,7 @@
 #'   alternatig colors (white and light grey by default).
 #' @param digits Numeric, amount of digits after decimal point when rounding
 #'   values.
+#' @param rnames Character vector, can be used to set row names when \code{show.rownames=TRUE}.
 #' @param ... Currently not used.
 #'
 #' @inheritParams tab_model
@@ -88,8 +89,6 @@
 #' # sort 2nd column descending
 #' tab_df(iris[1:5, ], sort.column = -2)}
 #'
-#' @importFrom sjmisc var_type is_even is_float
-#' @importFrom purrr flatten_chr map
 #' @export
 tab_df <- function(x,
                    title = NULL,
@@ -169,8 +168,6 @@ tab_df <- function(x,
 }
 
 
-#' @importFrom sjmisc var_type is_even
-#' @importFrom purrr flatten_chr pmap
 #' @rdname tab_df
 #' @export
 tab_dfs <- function(x,
@@ -187,6 +184,7 @@ tab_dfs <- function(x,
                     CSS = NULL,
                     file = NULL,
                     use.viewer = TRUE,
+                    rnames = NULL,
                     ...) {
 
   # make sure list elements in CSS argument have proper name attribute
@@ -201,10 +199,10 @@ tab_dfs <- function(x,
   if (is.null(footnotes)) footnotes <- rep("", length(x))
 
   if (length(titles) != length(x))
-    stop("Number of elements in `title` does not match number of data frames to print.", call. = F)
+    stop("Number of elements in `title` does not match number of data frames to print.", call. = FALSE)
 
   if (length(footnotes) != length(x))
-    stop("Number of elements in `footnote` does not match number of data frames to print.", call. = F)
+    stop("Number of elements in `footnote` does not match number of data frames to print.", call. = FALSE)
 
 
   # get HTML content
@@ -217,6 +215,14 @@ tab_dfs <- function(x,
             .i
         })
 
+        if (isTRUE(show.rownames)) {
+          if (!is.null(rnames)) {
+            tmp_rnames <- rnames
+          } else {
+            tmp_rnames <- row.names(dat)
+          }
+        }
+
         tab_df_content(
           mydf = dat,
           title = title,
@@ -228,6 +234,7 @@ tab_dfs <- function(x,
           altr.row.col = alternate.rows,
           sort.column = sort.column,
           include.table.tag = TRUE,
+          rnames = tmp_rnames,
           ...
         )
       })),
@@ -264,11 +271,7 @@ tab_dfs <- function(x,
   )
 }
 
-
 # this function is used from tab_model()
-#' @importFrom dplyr slice full_join
-#' @importFrom sjmisc replace_na
-#' @importFrom purrr map map_dbl
 tab_model_df <- function(x,
                          zeroinf,
                          is.zeroinf,
@@ -288,6 +291,7 @@ tab_model_df <- function(x,
                          col.header = NULL,
                          show.re.var = FALSE,
                          show.icc = FALSE,
+                         digits.rsq = 3,
                          digits.re = 2,
                          encoding = "UTF-8",
                          CSS = NULL,
@@ -432,9 +436,9 @@ tab_model_df <- function(x,
     rem <- 1:nrow(x)
 
     zero.part <- suppressMessages(
-      x %>%
-        dplyr::full_join(zeroinf) %>%
-        dplyr::slice(!! -rem) %>%
+      x |>
+        dplyr::full_join(zeroinf) |>
+        dplyr::slice(!! -rem) |>
         sjmisc::replace_na(value = "")
     )
 
@@ -512,6 +516,8 @@ tab_model_df <- function(x,
 
       }
     }
+    page.content <- paste0(page.content, "  </tr>\n")
+
 
 
     # random effects: Between-group-variance: tau.00 ----
@@ -719,10 +725,12 @@ tab_model_df <- function(x,
         page.content <- paste0(
           page.content,
           sprintf(
-            "    <td class=\"%s\" colspan=\"%i\">%.3f / %.3f</td>\n",
+            "    <td class=\"%s\" colspan=\"%i\">%.*f / %.*f</td>\n",
             s_css,
             as.integer(colspan),
+            digits.rsq,
             rsq.list[[i]][[1]],
+            digits.rsq,
             rsq.list[[i]][[2]]
           )
         )
@@ -732,9 +740,10 @@ tab_model_df <- function(x,
         page.content <- paste0(
           page.content,
           sprintf(
-            "    <td class=\"%s\" colspan=\"%i\">%.3f</td>\n",
+            "    <td class=\"%s\" colspan=\"%i\">%.*f</td>\n",
             s_css,
             as.integer(colspan),
+            digits.rsq,
             rsq.list[[i]][[1]]
           )
         )
