@@ -53,7 +53,7 @@ utils::globalVariables("density")
 #'          If not specified, a default labelling  is chosen.
 #'          \strong{Note:} Some plot types do not support this argument. In such
 #'          cases, use the return value and add axis titles manually with
-#'          \code{\link[ggplot2]{labs}}, e.g.: \code{$plot.list[[1]] + labs(x = ...)}
+#'          \code{\link[ggplot2]{labs}}, e.g.: \code{$plot.list[[1]] + ggplot2::labs(x = ...)}
 #'
 #' @inheritParams plot_scatter
 #' @inheritParams plot_grpfrq
@@ -75,8 +75,8 @@ utils::globalVariables("density")
 #'
 #' if (require("dplyr")) {
 #'   # histogram, pipe-workflow
-#'   efc %>%
-#'     dplyr::select(e17age, c160age) %>%
+#'   efc |>
+#'     dplyr::select(e17age, c160age) |>
 #'     plot_frq(type = "hist", show.mean = TRUE)
 #'
 #'   # bar plot(s)
@@ -85,9 +85,9 @@ utils::globalVariables("density")
 #'
 #' if (require("dplyr") && require("gridExtra")) {
 #'   # grouped data frame, all panels in one plot
-#'   efc %>%
-#'     group_by(e42dep) %>%
-#'     plot_frq(c161sex) %>%
+#'   efc |>
+#'     group_by(e42dep) |>
+#'     plot_frq(c161sex) |>
 #'     plot_grid()
 #' }
 #'
@@ -109,60 +109,56 @@ utils::globalVariables("density")
 #'         normal.curve = TRUE, show.sd = TRUE, normal.curve.color = "blue",
 #'         normal.curve.size = 3, ylim = c(0,50))
 #' }
-#' @import ggplot2
-#' @importFrom sjstats weighted_sd
-#' @importFrom sjmisc group_labels group_var to_value frq
-#' @importFrom sjlabelled set_labels drop_labels
-#' @importFrom stats na.omit sd weighted.mean dnorm
 #' @importFrom rlang .data
 #' @export
-plot_frq <- function(data,
-                     ...,
-                    title = "",
-                    weight.by = NULL,
-                    title.wtd.suffix = NULL,
-                    sort.frq = c("none", "asc", "desc"),
-                    type = c("bar", "dot", "histogram", "line", "density", "boxplot", "violin"),
-                    geom.size = NULL,
-                    geom.colors = "#336699",
-                    errorbar.color = "darkred",
-                    axis.title = NULL,
-                    axis.labels = NULL,
-                    xlim = NULL,
-                    ylim = NULL,
-                    wrap.title = 50,
-                    wrap.labels = 20,
-                    grid.breaks = NULL,
-                    expand.grid = FALSE,
-                    show.values = TRUE,
-                    show.n = TRUE,
-                    show.prc = TRUE,
-                    show.axis.values = TRUE,
-                    show.ci = FALSE,
-                    show.na = FALSE,
-                    show.mean = FALSE,
-                    show.mean.val = TRUE,
-                    show.sd = TRUE,
-                    drop.empty = TRUE,
-                    mean.line.type = 2,
-                    mean.line.size = 0.5,
-                    inner.box.width = 0.15,
-                    inner.box.dotsize = 3,
-                    normal.curve = FALSE,
-                    normal.curve.color = "red",
-                    normal.curve.size = 0.8,
-                    normal.curve.alpha = 0.4,
-                    auto.group = NULL,
-                    coord.flip = FALSE,
-                    vjust = "bottom",
-                    hjust = "center",
-                    y.offset = NULL) {
-
+plot_frq <- function(
+  data,
+  ...,
+  title = "",
+  weight.by = NULL,
+  title.wtd.suffix = NULL,
+  sort.frq = c("none", "asc", "desc"),
+  type = c("bar", "dot", "histogram", "line", "density", "boxplot", "violin"),
+  geom.size = NULL,
+  geom.colors = "#336699",
+  errorbar.color = "darkred",
+  axis.title = NULL,
+  axis.labels = NULL,
+  xlim = NULL,
+  ylim = NULL,
+  wrap.title = 50,
+  wrap.labels = 20,
+  grid.breaks = NULL,
+  expand.grid = FALSE,
+  show.values = TRUE,
+  show.n = TRUE,
+  show.prc = TRUE,
+  show.axis.values = TRUE,
+  show.ci = FALSE,
+  show.na = FALSE,
+  show.mean = FALSE,
+  show.mean.val = TRUE,
+  show.sd = TRUE,
+  drop.empty = TRUE,
+  mean.line.type = 2,
+  mean.line.size = 0.5,
+  inner.box.width = 0.15,
+  inner.box.dotsize = 3,
+  normal.curve = FALSE,
+  normal.curve.color = "red",
+  normal.curve.size = 0.8,
+  normal.curve.alpha = 0.4,
+  auto.group = NULL,
+  coord.flip = FALSE,
+  vjust = "bottom",
+  hjust = "center",
+  y.offset = NULL
+) {
   # Match arguments -----
   type <- match.arg(type)
   sort.frq <- match.arg(sort.frq)
 
-  plot_data  <- get_dplyr_dot_data(data, dplyr::quos(...))
+  plot_data <- get_dplyr_dot_data(data, dplyr::quos(...))
 
   if (!is.data.frame(plot_data)) {
     plot_data <- data.frame(plot_data, stringsAsFactors = FALSE)
@@ -187,13 +183,47 @@ plot_frq <- function(data,
 
       plots <- lapply(colnames(tmp), function(.d) {
         plot_frq_helper(
-          var.cnt = tmp[[.d]], title = tmp.title, weight.by = weight.by, title.wtd.suffix, sort.frq, type, geom.size, geom.colors,
-          errorbar.color, axis.title, axis.labels, xlim, ylim, wrap.title, wrap.labels, grid.breaks,
-          expand.grid, show.values, show.n, show.prc, show.axis.values, show.ci, show.na,
-          show.mean, show.mean.val, show.sd, drop.empty, mean.line.type, mean.line.size,
-          inner.box.width, inner.box.dotsize, normal.curve, normal.curve.color,
-          normal.curve.size, normal.curve.alpha, auto.group, coord.flip, vjust,
-          hjust, y.offset, var.name = .d
+          var.cnt = tmp[[.d]],
+          title = tmp.title,
+          weight.by = weight.by,
+          title.wtd.suffix,
+          sort.frq,
+          type,
+          geom.size,
+          geom.colors,
+          errorbar.color,
+          axis.title,
+          axis.labels,
+          xlim,
+          ylim,
+          wrap.title,
+          wrap.labels,
+          grid.breaks,
+          expand.grid,
+          show.values,
+          show.n,
+          show.prc,
+          show.axis.values,
+          show.ci,
+          show.na,
+          show.mean,
+          show.mean.val,
+          show.sd,
+          drop.empty,
+          mean.line.type,
+          mean.line.size,
+          inner.box.width,
+          inner.box.dotsize,
+          normal.curve,
+          normal.curve.color,
+          normal.curve.size,
+          normal.curve.alpha,
+          auto.group,
+          coord.flip,
+          vjust,
+          hjust,
+          y.offset,
+          var.name = .d
         )
       })
 
@@ -203,13 +233,47 @@ plot_frq <- function(data,
   } else {
     pl <- lapply(colnames(plot_data), function(.d) {
       plot_frq_helper(
-        var.cnt = plot_data[[.d]], title, weight.by = weight.by, title.wtd.suffix, sort.frq, type, geom.size, geom.colors,
-        errorbar.color, axis.title, axis.labels, xlim, ylim, wrap.title, wrap.labels, grid.breaks,
-        expand.grid, show.values, show.n, show.prc, show.axis.values, show.ci, show.na,
-        show.mean, show.mean.val, show.sd, drop.empty, mean.line.type, mean.line.size,
-        inner.box.width, inner.box.dotsize, normal.curve, normal.curve.color,
-        normal.curve.size, normal.curve.alpha, auto.group, coord.flip, vjust,
-        hjust, y.offset, var.name = .d
+        var.cnt = plot_data[[.d]],
+        title,
+        weight.by = weight.by,
+        title.wtd.suffix,
+        sort.frq,
+        type,
+        geom.size,
+        geom.colors,
+        errorbar.color,
+        axis.title,
+        axis.labels,
+        xlim,
+        ylim,
+        wrap.title,
+        wrap.labels,
+        grid.breaks,
+        expand.grid,
+        show.values,
+        show.n,
+        show.prc,
+        show.axis.values,
+        show.ci,
+        show.na,
+        show.mean,
+        show.mean.val,
+        show.sd,
+        drop.empty,
+        mean.line.type,
+        mean.line.size,
+        inner.box.width,
+        inner.box.dotsize,
+        normal.curve,
+        normal.curve.color,
+        normal.curve.size,
+        normal.curve.alpha,
+        auto.group,
+        coord.flip,
+        vjust,
+        hjust,
+        y.offset,
+        var.name = .d
       )
     })
 
@@ -221,59 +285,108 @@ plot_frq <- function(data,
 
 
 plot_frq_helper <- function(
-  var.cnt, title, weight.by, title.wtd.suffix, sort.frq, type, geom.size, geom.colors,
-  errorbar.color, axis.title, axis.labels, xlim, ylim, wrap.title, wrap.labels, grid.breaks,
-  expand.grid, show.values, show.n, show.prc, show.axis.values, show.ci, show.na,
-  show.mean, show.mean.val, show.sd, drop.empty, mean.line.type, mean.line.size,
-  inner.box.width, inner.box.dotsize, normal.curve, normal.curve.color,
-  normal.curve.size, normal.curve.alpha, auto.group, coord.flip, vjust,
-  hjust, y.offset, var.name = NULL) {
-
+  var.cnt,
+  title,
+  weight.by,
+  title.wtd.suffix,
+  sort.frq,
+  type,
+  geom.size,
+  geom.colors,
+  errorbar.color,
+  axis.title,
+  axis.labels,
+  xlim,
+  ylim,
+  wrap.title,
+  wrap.labels,
+  grid.breaks,
+  expand.grid,
+  show.values,
+  show.n,
+  show.prc,
+  show.axis.values,
+  show.ci,
+  show.na,
+  show.mean,
+  show.mean.val,
+  show.sd,
+  drop.empty,
+  mean.line.type,
+  mean.line.size,
+  inner.box.width,
+  inner.box.dotsize,
+  normal.curve,
+  normal.curve.color,
+  normal.curve.size,
+  normal.curve.alpha,
+  auto.group,
+  coord.flip,
+  vjust,
+  hjust,
+  y.offset,
+  var.name = NULL
+) {
   # remove empty value-labels
   if (drop.empty) {
     var.cnt <- sjlabelled::drop_labels(var.cnt)
   }
 
-
   # try to find some useful default offsets for textlabels,
   # depending on plot range and flipped coordinates
   if (is.null(y.offset)) {
     # get maximum y-pos
     y.offset <- ceiling(max(table(var.cnt)) / 100)
     if (coord.flip) {
-      if (missing(vjust)) vjust <- "center"
-      if (missing(hjust)) hjust <- "bottom"
-      if (hjust == "bottom")
+      if (missing(vjust)) {
+        vjust <- "center"
+      }
+      if (missing(hjust)) {
+        hjust <- "bottom"
+      }
+      if (hjust == "bottom") {
         y_offset <- y.offset
-      else if (hjust == "top")
+      } else if (hjust == "top") {
         y_offset <- -y.offset
-      else
+      } else {
         y_offset <- 0
+      }
     } else {
-      if (vjust == "bottom")
+      if (vjust == "bottom") {
         y_offset <- y.offset
-      else if (vjust == "top")
+      } else if (vjust == "top") {
         y_offset <- -y.offset
-      else
+      } else {
         y_offset <- 0
+      }
     }
   } else {
     y_offset <- y.offset
   }
 
-  if (is.null(axis.title)) axis.title <- sjlabelled::get_label(var.cnt, def.value = var.name)
-  if (is.null(title)) title <- sjlabelled::get_label(var.cnt, def.value = var.name)
+  if (is.null(axis.title)) {
+    axis.title <- sjlabelled::get_label(var.cnt, def.value = var.name)
+  }
+  if (is.null(title)) {
+    title <- sjlabelled::get_label(var.cnt, def.value = var.name)
+  }
 
   # remove titles if empty
-  if (!is.null(axis.title) && axis.title == "") axis.title <- NULL
-  if (!is.null(title) && title == "") title <- NULL
+  if (!is.null(axis.title) && axis.title == "") {
+    axis.title <- NULL
+  }
+  if (!is.null(title) && title == "") {
+    title <- NULL
+  }
 
   # check color argument
-  if (length(geom.colors) > 1) geom.colors <- geom.colors[1]
+  if (length(geom.colors) > 1) {
+    geom.colors <- geom.colors[1]
+  }
 
   # default grid-expansion
   if (isTRUE(expand.grid) || (missing(expand.grid) && type == "histogram")) {
-    expand.grid <- waiver()
+    expand.grid <- ggplot2::waiver()
   } else {
     expand.grid <- c(0, 0)
   }
@@ -282,10 +395,16 @@ plot_frq_helper <- function(
   xv <- sjmisc::to_value(stats::na.omit(var.cnt))
 
   # check for nice bin-width defaults
-  if (type %in% c("histogram", "density") &&
+  if (
+    type %in%
+      c("histogram", "density") &&
       !is.null(geom.size) &&
-      geom.size < round(diff(range(xv)) / 40))
-    message("Using very small binwidth. Consider adjusting `geom.size` argument.")
+      geom.size < round(diff(range(xv)) / 40)
+  ) {
+    message(
+      "Using very small binwidth. Consider adjusting `geom.size` argument."
+    )
+  }
 
   # create second data frame
   hist.dat <- data.frame(xv)
@@ -338,7 +457,9 @@ plot_frq_helper <- function(
 
   mydat <- df.frq[[1]]
   # remove empty
-  if (drop.empty) mydat <- mydat[mydat$frq > 0, ]
+  if (drop.empty) {
+    mydat <- mydat[mydat$frq > 0, ]
+  }
 
   # add confindence intervals for frequencies
   total_n = sum(mydat$frq)
@@ -350,35 +471,45 @@ plot_frq_helper <- function(
   mydat$rel.lower.ci <- rel_frq - ci
 
   # any labels detected?
-  if (!is.null(mydat$label) && is.null(axis.labels) && !all(stats::na.omit(mydat$label) == "<none>"))
+  if (
+    !is.null(mydat$label) &&
+      is.null(axis.labels) &&
+      !all(stats::na.omit(mydat$label) == "<none>")
+  ) {
     axis.labels <- mydat$label
-  else if (is.null(axis.labels))
+  } else if (is.null(axis.labels)) {
     axis.labels <- mydat$val
+  }
 
   # wrap labels
   axis.labels <- sjmisc::word_wrap(axis.labels, wrap.labels)
 
   # define text label position
-  if (show.ci)
+  if (show.ci) {
     mydat$label.pos <- mydat$upper.ci
-  else
+  } else {
     mydat$label.pos <- mydat$frq
+  }
 
   # Trim labels and title to appropriate size -----
   # check length of diagram title and split longer string into new lines
   # every 50 chars
   if (!is.null(title)) {
     # if we have weighted values, say that in diagram's title
-    if (!is.null(title.wtd.suffix)) title <- paste(title, title.wtd.suffix, sep = "")
+    if (!is.null(title.wtd.suffix)) {
+      title <- paste(title, title.wtd.suffix, sep = "")
+    }
     title <- sjmisc::word_wrap(title, wrap.title)
   }
   # check length of x-axis title and split longer string into new lines
   # every 50 chars
-  if (!is.null(axis.title)) axis.title <- sjmisc::word_wrap(axis.title, wrap.title)
+  if (!is.null(axis.title)) {
+    axis.title <- sjmisc::word_wrap(axis.title, wrap.title)
+  }
 
   # count variable may not be a factor!
   if (is.factor(var.cnt) || is.character(var.cnt)) {
-    var.cnt <- sjmisc::to_value(var.cnt, keep.labels = F)
+    var.cnt <- sjmisc::to_value(var.cnt, keep.labels = FALSE)
   }
 
   # If we have a histogram, caluclate means of groups
@@ -387,7 +518,7 @@ plot_frq_helper <- function(
     stddev <- stats::sd(var.cnt, na.rm = TRUE)
   } else {
     mittelwert <- stats::weighted.mean(var.cnt, weight.by, na.rm = TRUE)
-    stddev <- sjstats::weighted_sd(var.cnt, weights = weight.by)
+    stddev <- datawizard::weighted_sd(var.cnt, weights = weight.by)
   }
 
   # If we have boxplots, use different data frame structure
@@ -414,8 +545,10 @@ plot_frq_helper <- function(
     # the y axis
     if (type == "boxplot" || type == "violin") {
       # use an extra standard-deviation as limits for the y-axis when we have boxplots
-      lower_lim <- min(var.cnt, na.rm = TRUE) - floor(stats::sd(var.cnt, na.rm = TRUE))
-      upper_lim <- max(var.cnt, na.rm = TRUE) + ceiling(stats::sd(var.cnt, na.rm = TRUE))
+      lower_lim <- min(var.cnt, na.rm = TRUE) -
+        floor(stats::sd(var.cnt, na.rm = TRUE))
+      upper_lim <- max(var.cnt, na.rm = TRUE) +
+        ceiling(stats::sd(var.cnt, na.rm = TRUE))
       # make sure that the y-axis is not below zero
       if (lower_lim < 0) {
         lower_lim <- 0
@@ -423,85 +556,97 @@ plot_frq_helper <- function(
       }
     } else if (type == "histogram") {
       # what is the maximum values after binning for histograms?
-      hist.grp.cnt <- ceiling(diff(range(var.cnt, na.rm = T)) / geom.size)
+      hist.grp.cnt <- ceiling(diff(range(var.cnt, na.rm = TRUE)) / geom.size)
       # ... or the amount of max. answers per category
       # add 10% margin to upper limit
-      upper_lim <- max(pretty(table(
-        sjmisc::group_var(
-          var.cnt,
-          size = "auto",
-          n = hist.grp.cnt,
-          append = FALSE
-        )
-      ) * 1.1))
+      upper_lim <- max(pretty(
+        table(
+          sjmisc::group_var(
+            var.cnt,
+            size = "auto",
+            n = hist.grp.cnt,
+            append = FALSE
+          )
+        ) *
+          1.1
+      ))
     } else {
-      if (show.ci)
+      if (show.ci) {
         upper_lim <- max(pretty(mydat$upper.ci * 1.1))
-      else
+      } else {
         upper_lim <- max(pretty(mydat$frq * 1.1))
+      }
     }
   }
 
   # If we want to include NA, use raw percentages as valid percentages
-  if (show.na) mydat$valid.prc <- mydat$raw.prc
+  if (show.na) {
+    mydat$valid.prc <- mydat$raw.prc
+  }
 
   # don't display value labels when we have boxplots or violin plots
-  if (type == "boxplot" || type == "violin") show.values <- FALSE
+  if (type == "boxplot" || type == "violin") {
+    show.values <- FALSE
+  }
   if (show.values) {
     # here we have counts and percentages
     if (show.prc && show.n) {
       if (coord.flip) {
         ggvaluelabels <-
-          geom_text(
+          ggplot2::geom_text(
             label = sprintf("%i (%.01f%%)", mydat$frq, mydat$valid.prc),
             hjust = hjust,
             vjust = vjust,
-            aes(y = .data$label.pos + y_offset)
+            ggplot2::aes(y = .data$label.pos + y_offset)
           )
       } else {
         ggvaluelabels <-
-          geom_text(
+          ggplot2::geom_text(
             label = sprintf("%i\n(%.01f%%)", mydat$frq, mydat$valid.prc),
             hjust = hjust,
             vjust = vjust,
-            aes(y = .data$label.pos + y_offset)
+            ggplot2::aes(y = .data$label.pos + y_offset)
           )
       }
     } else if (show.n) {
       # here we have counts, without percentages
-      ggvaluelabels <-  geom_text(
+      ggvaluelabels <- ggplot2::geom_text(
         label = sprintf("%i", mydat$frq),
         hjust = hjust,
         vjust = vjust,
-        aes(y = .data$label.pos + y_offset)
+        ggplot2::aes(y = .data$label.pos + y_offset)
       )
     } else if (show.prc) {
       # here we have counts, without percentages
       ggvaluelabels <-
-        geom_text(
+        ggplot2::geom_text(
           label = sprintf("%.01f%%", mydat$valid.prc),
           hjust = hjust,
           vjust = vjust,
-          aes(y = .data$label.pos + y_offset)
+          ggplot2::aes(y = .data$label.pos + y_offset)
         )
     } else {
       # no labels
-      ggvaluelabels <-  geom_text(aes(y = .data$frq), label = "")
+      ggvaluelabels <- ggplot2::geom_text(
+        ggplot2::aes(y = .data$frq),
+        label = ""
+      )
     }
   } else {
     # no labels
-    ggvaluelabels <-  geom_text(aes(y = .data$frq), label = "")
+    ggvaluelabels <- ggplot2::geom_text(ggplot2::aes(y = .data$frq), label = "")
   }
 
   # Set up grid breaks
-  maxx <- if (is.numeric(mydat$val))
+  maxx <- if (is.numeric(mydat$val)) {
     max(mydat$val) + 1
-  else
+  } else {
     nrow(mydat)
+  }
 
   if (is.null(grid.breaks)) {
-    gridbreaks <- waiver()
-    histgridbreaks <- waiver()
+    gridbreaks <- ggplot2::waiver()
+    histgridbreaks <- ggplot2::waiver()
   } else {
     gridbreaks <- c(seq(lower_lim, upper_lim, by = grid.breaks))
     histgridbreaks <- c(seq(lower_lim, maxx, by = grid.breaks))
@@ -511,13 +656,13 @@ plot_frq_helper <- function(
   # It either corresponds to the maximum amount of cases in the data set
   # (length of var) or to the highest count of var's categories.
   if (show.axis.values) {
-    yscale <- scale_y_continuous(
+    yscale <- ggplot2::scale_y_continuous(
       limits = c(lower_lim, upper_lim),
       expand = expand.grid,
       breaks = gridbreaks
     )
   } else {
-    yscale <- scale_y_continuous(
+    yscale <- ggplot2::scale_y_continuous(
       limits = c(lower_lim, upper_lim),
       expand = expand.grid,
       breaks = gridbreaks,
@@ -529,9 +674,13 @@ plot_frq_helper <- function(
   if (type == "bar" || type == "dot") {
     # define geom
     if (type == "bar") {
-      geob <- geom_bar(stat = "identity", width = geom.size, fill = geom.colors)
+      geob <- ggplot2::geom_bar(
+        stat = "identity",
+        width = geom.size,
+        fill = geom.colors
+      )
     } else if (type == "dot") {
-      geob <- geom_point(size = geom.size, colour = geom.colors)
+      geob <- ggplot2::geom_point(size = geom.size, colour = geom.colors)
     }
 
     # as factor, but preserve order
@@ -540,50 +689,60 @@ plot_frq_helper <- function(
     # mydat is a data frame that only contains one variable (var).
     # Must be declared as factor, so the bars are central aligned to
     # each x-axis-break.
-    baseplot <- ggplot(mydat, aes(x = .data$val, y = .data$frq)) +
+    baseplot <- ggplot2::ggplot(
+      mydat,
+      ggplot2::aes(x = .data$val, y = .data$frq)
+    ) +
       geob +
       yscale +
       # remove guide / legend
-      guides(fill = "none") +
+      ggplot2::guides(fill = "none") +
       # show absolute and percentage value of each bar.
       ggvaluelabels +
       # print value labels to the x-axis.
       # If argument "axis.labels" is NULL, the category numbers (1 to ...)
       # appear on the x-axis
-      scale_x_discrete(labels = axis.labels)
+      ggplot2::scale_x_discrete(labels = axis.labels)
 
     # add error bars
     if (show.ci) {
       ebcol <- ifelse(type == "dot", geom.colors, errorbar.color)
       # print confidence intervalls (error bars)
       baseplot <- baseplot +
-        geom_errorbar(aes_string(ymin = "lower.ci", ymax = "upper.ci"), colour = ebcol, width = 0)
+        ggplot2::geom_errorbar(
+          ggplot2::aes(ymin = .data$lower.ci, ymax = .data$upper.ci),
+          colour = ebcol,
+          width = 0
+        )
     }
 
     # check whether coordinates should be flipped, i.e.
     # swap x and y axis
-    if (coord.flip) baseplot <- baseplot + coord_flip()
+    if (coord.flip) baseplot <- baseplot + ggplot2::coord_flip()
 
-  # Start box plot here -----
+    # Start box plot here -----
   } else if (type == "boxplot" || type == "violin") {
     # setup base plot
-    baseplot <- ggplot(mydat, aes_string(x = "grp", y = "frq"))
+    baseplot <- ggplot2::ggplot(
+      mydat,
+      ggplot2::aes(x = .data$grp, y = .data$frq)
+    )
     # and x-axis
-    scalex <- scale_x_discrete(labels = "")
+    scalex <- ggplot2::scale_x_discrete(labels = "")
     if (type == "boxplot") {
       baseplot <- baseplot +
-        geom_boxplot(width = geom.size, fill = geom.colors, notch = show.ci)
+        ggplot2::geom_boxplot(width = geom.size, fill = geom.colors, notch = show.ci)
     } else {
       baseplot <- baseplot +
-        geom_violin(trim = trimViolin, width = geom.size, fill = geom.colors)
+        ggplot2::geom_violin(trim = trimViolin, width = geom.size, fill = geom.colors)
       # if we have a violin plot, add an additional boxplot inside to show
       # more information
       if (show.ci) {
         baseplot <- baseplot +
-          geom_boxplot(width = inner.box.width, fill = "white", notch = TRUE)
+          ggplot2::geom_boxplot(width = inner.box.width, fill = "white", notch = TRUE)
       } else {
         baseplot <- baseplot +
-          geom_boxplot(width = inner.box.width, fill = "white")
+          ggplot2::geom_boxplot(width = inner.box.width, fill = "white")
       }
     }
 
@@ -592,27 +751,44 @@ plot_frq_helper <- function(
     # different fill colours, because violin boxplots have white background
     fcsp <- ifelse(type == "boxplot", "white", "black")
     baseplot <- baseplot +
-      stat_summary(fun.y = "mean", geom = "point", shape = 21,
-                   size = inner.box.dotsize, fill = fcsp)
+      ggplot2::stat_summary(
+        fun = "mean",
+        geom = "point",
+        shape = 21,
+        size = inner.box.dotsize,
+        fill = fcsp
+      )
     # no additional labels for the x- and y-axis, only diagram title
     baseplot <- baseplot + yscale + scalex
 
-  # Start density plot here -----
+    # Start density plot here -----
   } else if (type == "density") {
     # First, plot histogram with density curve
-    baseplot <- ggplot(hist.dat, aes(x = .data$xv)) +
-      geom_histogram(aes(y = stat(density)), binwidth = geom.size, fill = geom.colors) +
+    baseplot <- ggplot2::ggplot(hist.dat, ggplot2::aes(x = .data$xv)) +
+      ggplot2::geom_histogram(
+        ggplot2::aes(y = ggplot2::after_stat(density)),
+        binwidth = geom.size,
+        fill = geom.colors
+      ) +
       # transparent density curve above bars
-      geom_density(aes(y = stat(density)), fill = "cornsilk", alpha = 0.3) +
+      ggplot2::geom_density(
+        ggplot2::aes(y = ggplot2::after_stat(density)),
+        fill = "cornsilk",
+        alpha = 0.3
+      ) +
       # remove margins from left and right diagram side
-      scale_x_continuous(expand = expand.grid, breaks = histgridbreaks, limits = xlim)
+      ggplot2::scale_x_continuous(
+        expand = expand.grid,
+        breaks = histgridbreaks,
+        limits = xlim
+      )
 
     # check whether user wants to overlay the histogram
     # with a normal curve
     if (normal.curve) {
       baseplot <- baseplot +
-        stat_function(
-          fun = dnorm,
+        ggplot2::stat_function(
+          fun = stats::dnorm,
           args = list(
             mean = mean(hist.dat$xv),
             sd = stats::sd(hist.dat$xv)
@@ -628,28 +804,39 @@ plot_frq_helper <- function(
     # counts on the y-axis
     if (type == "histogram") {
       # original data needed for normal curve
-      baseplot <- ggplot(mydat) +
+      baseplot <- ggplot2::ggplot(mydat) +
         # second data frame mapped to the histogram geom
-        geom_histogram(data = hist.dat, aes(x = .data$xv), binwidth = geom.size, fill = geom.colors)
+        ggplot2::geom_histogram(
+          data = hist.dat,
+          ggplot2::aes(x = .data$xv),
+          binwidth = geom.size,
+          fill = geom.colors
+        )
     } else {
-      baseplot <- ggplot(mydat, aes(x = .data$val, y = .data$frq)) +
-        geom_area(alpha = 0.3) +
-        geom_line(size = geom.size, colour = geom.colors) +
+      baseplot <- ggplot2::ggplot(
+        mydat,
+        ggplot2::aes(x = .data$val, y = .data$frq)
+      ) +
+        ggplot2::geom_area(alpha = 0.3) +
+        ggplot2::geom_line(linewidth = geom.size, colour = geom.colors) +
         ggvaluelabels
     }
     # check whether user wants to overlay the histogram
     # with a normal curve
     if (normal.curve) {
       baseplot <- baseplot +
-        stat_function(
+        ggplot2::stat_function(
           fun = function(xx, mean, sd, n) {
             n * stats::dnorm(x = xx, mean = mean, sd = sd)
           },
-          args = with(mydat, c(
-            mean = mittelwert,
-            sd = stddev,
-            n = length(var.cnt)
-          )),
+          args = with(
+            mydat,
+            c(
+              mean = mittelwert,
+              sd = stddev,
+              n = length(var.cnt)
+            )
+          ),
           colour = normal.curve.color,
           size = normal.curve.size,
           alpha = normal.curve.alpha
@@ -659,12 +846,16 @@ plot_frq_helper <- function(
     if (show.mean) {
       baseplot <- baseplot +
         # vertical lines indicating the mean
-        geom_vline(xintercept = mittelwert, linetype = mean.line.type, size = mean.line.size)
+        ggplot2::geom_vline(
+          xintercept = mittelwert,
+          linetype = mean.line.type,
+          size = mean.line.size
+        )
       # check whether meanvalue should be shown.
       if (show.mean.val) {
         baseplot <- baseplot +
           # use annotation instead of geomtext, because we need mean value only printed once
-          annotate(
+          ggplot2::annotate(
             "text",
             x = mittelwert,
             y = upper_lim,
@@ -683,33 +874,44 @@ plot_frq_helper <- function(
       if (show.sd) {
         baseplot <- baseplot +
           # first draw shaded rectangle. these are by default in grey colour with very high transparancy
-          annotate("rect",
-                   xmin = mittelwert - stddev,
-                   xmax = mittelwert + stddev,
-                   ymin = 0,
-                   ymax = c(upper_lim),
-                   fill = "grey70",
-                   alpha = 0.2) +
+          ggplot2::annotate(
+            "rect",
+            xmin = mittelwert - stddev,
+            xmax = mittelwert + stddev,
+            ymin = 0,
+            ymax = c(upper_lim),
+            fill = "grey70",
+            alpha = 0.2
+          ) +
           # draw border-lines for shaded rectangle
-          geom_vline(xintercept = mittelwert - stddev,
-                     linetype = 3,
-                     size = mean.line.size,
-                     alpha = 0.7) +
-          geom_vline(xintercept = mittelwert + stddev,
-                     linetype = 3,
-                     size = mean.line.size,
-                     alpha = 0.7)
+          ggplot2::geom_vline(
+            xintercept = mittelwert - stddev,
+            linetype = 3,
+            size = mean.line.size,
+            alpha = 0.7
+          ) +
+          ggplot2::geom_vline(
+            xintercept = mittelwert + stddev,
+            linetype = 3,
+            size = mean.line.size,
+            alpha = 0.7
+          )
       }
     }
 
     # show absolute and percentage value of each bar.
-    baseplot <- baseplot + yscale +
+    baseplot <- baseplot +
+      yscale +
       # continuous x-scale for histograms
-      scale_x_continuous(limits = xlim, expand = expand.grid, breaks = histgridbreaks)
+      ggplot2::scale_x_continuous(
+        limits = xlim,
+        expand = expand.grid,
+        breaks = histgridbreaks
+      )
   }
 
   # set axes text and
-  baseplot <- baseplot + labs(title = title, x = axis.title, y = NULL)
+  baseplot <- baseplot + ggplot2::labs(title = title, x = axis.title, y = NULL)
 
   # Check whether ggplot object should be returned or plotted
   baseplot
