@@ -18,37 +18,38 @@
 #'          To arrange these plots as grid as a single plot, use \code{plot_grid}.
 #'
 #' @examples
-#' library(ggeffects)
-#' data(efc)
+#' if (require("dplyr") && require("gridExtra")) {
+#'   library(ggeffects)
+#'   data(efc)
 #'
-#' # fit model
-#' fit <- glm(
-#'   tot_sc_e ~ c12hour + e17age + e42dep + neg_c_7,
-#'   data = efc,
-#'   family = poisson
-#' )
+#'   # fit model
+#'   fit <- glm(
+#'     tot_sc_e ~ c12hour + e17age + e42dep + neg_c_7,
+#'     data = efc,
+#'     family = poisson
+#'   )
 #'
-#' # plot marginal effects for each predictor, each as single plot
-#' p1 <- ggpredict(fit, "c12hour") %>%
-#'   plot(show.y.title = FALSE, show.title = FALSE)
-#' p2 <- ggpredict(fit, "e17age") %>%
-#'   plot(show.y.title = FALSE, show.title = FALSE)
-#' p3 <- ggpredict(fit, "e42dep") %>%
-#'   plot(show.y.title = FALSE, show.title = FALSE)
-#' p4 <- ggpredict(fit, "neg_c_7") %>%
-#'   plot(show.y.title = FALSE, show.title = FALSE)
+#'   # plot marginal effects for each predictor, each as single plot
+#'   p1 <- ggpredict(fit, "c12hour") |>
+#'     plot(show_y_title = FALSE, show_title = FALSE)
+#'   p2 <- ggpredict(fit, "e17age") |>
+#'     plot(show_y_title = FALSE, show_title = FALSE)
+#'   p3 <- ggpredict(fit, "e42dep") |>
+#'     plot(show_y_title = FALSE, show_title = FALSE)
+#'   p4 <- ggpredict(fit, "neg_c_7") |>
+#'     plot(show_y_title = FALSE, show_title = FALSE)
 #'
-#' # plot grid
-#' plot_grid(list(p1, p2, p3, p4))
-#'
-#' # plot grid
-#' plot_grid(list(p1, p2, p3, p4), tags = TRUE)
+#'   # plot grid
+#'   plot_grid(list(p1, p2, p3, p4))
 #'
+#'   # plot grid
+#'   plot_grid(list(p1, p2, p3, p4), tags = TRUE)
+#' }
 #' @export
 plot_grid <- function(x, margin = c(1, 1, 1, 1), tags = NULL) {
   # check package availability -----
   if (!requireNamespace("gridExtra", quietly = TRUE)) {
-    stop("Package `gridExtra` needed for this function to work. Please install it.", call. = F)
+    stop("Package `gridExtra` needed for this function to work. Please install it.", call. = FALSE)
   }
 
   # if user did not pass plot.list value, but the complete object returned
@@ -57,26 +58,24 @@ plot_grid <- function(x, margin = c(1, 1, 1, 1), tags = NULL) {
 
   # add margin to each plot, so no axis labels are cropped
   x <- lapply(x, function(pl) {
-    pl + theme(plot.margin = unit(margin, "cm"))
+    pl + ggplot2::theme(plot.margin = ggplot2::unit(margin, "cm"))
   })
 
   tags_labels <- NULL
 
   # Add tags
-  if (isTRUE(tags)) {
+  if (isTRUE(tags) || is.null(tags)) {
+    tags_labels = LETTERS
+  } else if (length(tags) < length(x)) {
+    insight::format_warning("Not enough tags labels in list. Using letters instead.")
     tags_labels = LETTERS
   } else{
-    if (length(tags) < length(x)) {
-      warning("Not enough tags labels in list. Using letters instead.")
-      tags_labels = LETTERS
-    } else{
-      tags_labels = tags
-    }
+    tags_labels = tags
   }
 
   if (!is.null(tags_labels)) {
     for (i in 1:length(x)) {
-      x[[i]] <- x[[i]] + labs(tag = tags_labels[i])
+      x[[i]] <- x[[i]] + ggplot2::labs(tag = tags_labels[i])
     }
   }
 
