@@ -115,6 +115,10 @@
 #' @param order.terms Numeric vector, indicating in which order the coefficients
 #'   should be plotted. See examples in
 #'   \href{https://strengejacke.github.io/sjPlot/articles/plot_model_estimates.html}{this package-vignette}.
+#' @param std.response Logical, whether the response variable will also be
+#'   standardized if standardized coefficients are requested. Setting both
+#'   \code{std.response = TRUE} and \code{show.std = TRUE} will behave as if
+#'   the complete data was standardized before fitting the model.
 #' @param pred.type Character, only applies for \emph{Marginal Effects} plots
 #'   with mixed effects models. Indicates whether predicted values should be
 #'   conditioned on random effects (\code{pred.type = "re"}) or fixed effects
@@ -187,9 +191,8 @@
 #'   \code{...}-argument for more details.
 #' @param se Logical, if \code{TRUE}, the standard errors are
 #'   also printed. If robust standard errors are required, use arguments
-#'   \code{vcov.fun}, \code{vcov.type} and \code{vcov.args} (see
-#'   \code{\link[parameters]{standard_error}} for details), or use argument
-#'   \code{robust} as shortcut. \code{se} overrides
+#'   \code{vcov.fun} and \code{vcov.args} (see
+#'   \code{\link[parameters]{standard_error}} for details). \code{se} overrides
 #'   \code{ci.lvl}: if not \code{NULL}, arguments \code{ci.lvl} and \code{transform}
 #'   will be ignored. Currently, \code{se} only applies to \emph{Coefficients} plots.
 #' @param show.intercept Logical, if \code{TRUE}, the intercept of the fitted
@@ -205,15 +208,11 @@
 #'   legend.
 #' @param show.zeroinf Logical, if \code{TRUE}, shows the zero-inflation part of
 #'   hurdle- or zero-inflated models.
-#' @param robust Deprecated. Please use \code{vcov.fun} directly to specify
-#'   the estimation of the variance-covariance matrix.
 #' @param vcov.fun Variance-covariance matrix used to compute uncertainty
 #'   estimates (e.g., for robust standard errors). This argument accepts a
 #'   covariance matrix, a function which returns a covariance matrix, or a
 #'   string which identifies the function to be used to compute the covariance
 #'   matrix. See \code{\link[parameters:model_parameters]{model_parameters()}}.
-#' @param vcov.type Deprecated. The \code{type}-argument is now included in
-#'   \code{vcov.args}.
 #' @param vcov.args List of arguments to be passed to the function identified by
 #'   the \code{vcov.fun} argument. This function is typically supplied by the
 #'   \pkg{sandwich} or \pkg{clubSandwich} packages. Please refer to their
@@ -270,7 +269,7 @@
 #'   will be occupied by the jittered values.
 #' @param digits Numeric, amount of digits after decimal point when rounding
 #'   estimates or values.
-#' @param p.adjust Character vector, if not \code{NULL}, indicates the method
+#' @param p.adjust String value, if not \code{NULL}, indicates the method
 #'   to adjust p-values. See \code{\link[stats]{p.adjust}} for details.
 #' @param value.size Numeric, indicates the size of value labels. Can be used
 #'   for all plot types where the argument \code{show.values} is applicable,
@@ -312,7 +311,7 @@
 #'       removes the inner probability regions.
 #'     }
 #'     \item{\code{width}, \code{alpha}, and \code{scale}}{Passed
-#'       down to \code{geom_errorbar()} or \code{geom_density_ridges()}, for
+#'       down to \code{ggplot2::geom_errorbar()} or \code{geom_density_ridges()}, for
 #'       forest or diagnostic plots.
 #'     }
 #'     \item{\code{width}, \code{alpha}, \code{dot.alpha}, \code{dodge} and \code{log.y}}{Passed
@@ -394,23 +393,23 @@
 #'   Default standardization is done by completely refitting the model on the
 #'   standardized data. Hence, this approach is equal to standardizing the
 #'   variables before fitting the model, which is particularly recommended for
-#'   complex models that include interactions or transformations (e.g., polynomial
-#'   or spline terms). When \code{type = "std2"}, standardization of estimates
-#'   follows \href{http://www.stat.columbia.edu/~gelman/research/published/standardizing7.pdf}{Gelman's (2008)}
-#'   suggestion, rescaling the estimates by dividing them by two standard deviations
-#'   instead of just one. Resulting coefficients are then directly comparable for
-#'   untransformed binary predictors.
+#'   complex models that include interactions or transformations (e.g.,
+#'   polynomial or spline terms). When \code{type = "std2"}, standardization of
+#'   estimates follows Gelman's (2008) suggestion, rescaling the estimates by
+#'   dividing them by two standard deviations instead of just one. Resulting
+#'   coefficients are then directly comparable for untransformed binary
+#'   predictors.
 #' }
 #'
 #' @references
 #'   Gelman A (2008) "Scaling regression inputs by dividing by two
 #'   standard deviations." \emph{Statistics in Medicine 27: 2865-2873.}
-#'   \url{http://www.stat.columbia.edu/~gelman/research/published/standardizing7.pdf}
 #'   \cr \cr
 #'   Aiken and West (1991). Multiple Regression: Testing and Interpreting Interactions.
 #'
 #' @examples
 #' # prepare data
+#' if (requireNamespace("haven")) {
 #' library(sjmisc)
 #' data(efc)
 #' efc <- to_factor(efc, c161sex, e42dep, c172code)
@@ -425,6 +424,7 @@
 #' # keep only selected terms in the model: pos_v_4, the
 #' # levels 3 and 4 of factor e42dep and levels 2 and 3 for c172code
 #' plot_model(m, terms = c("pos_v_4", "e42dep [3,4]", "c172code [2,3]"))
+#' }
 #'
 #' # multiple plots, as returned from "diagnostic"-plot type,
 #' # can be arranged with 'plot_grid()'
@@ -488,9 +488,7 @@ plot_model <- function(model,
                        grid.breaks = NULL,
                        ci.lvl = NULL,
                        se = NULL,
-                       robust = FALSE,
                        vcov.fun = NULL,
-                       vcov.type = NULL,
                        vcov.args = NULL,
                        colors = "Set1",
                        show.intercept = FALSE,
@@ -517,6 +515,7 @@ plot_model <- function(model,
                        bpe.style = "line",
                        bpe.color = "white",
                        ci.style = c("whisker", "bar"),
+                       std.response = TRUE,
                        ...
                        ) {
 
@@ -535,10 +534,6 @@ plot_model <- function(model,
       case <- NULL
   }
 
-  if (isTRUE(robust)) {
-    vcov.fun <- "HC3"
-  }
-
   # get info on model family
   fam.info <- insight::model_info(model)
 
@@ -652,10 +647,10 @@ plot_model <- function(model,
       p.threshold = p.threshold,
       p.val = p.val,
       vcov.fun = vcov.fun,
-      vcov.type = vcov.type,
       vcov.args = vcov.args,
       ci.style = ci.style,
       p_adjust = p.adjust,
+      std.response = std.response,
       ...
     )
 
@@ -801,7 +796,6 @@ plot_model <- function(model,
 }
 
 
-#' @importFrom purrr map
 #' @rdname plot_model
 #' @export
 get_model_data <- function(model,
@@ -848,7 +842,6 @@ get_model_data <- function(model,
 }
 
 
-#' @importFrom insight has_intercept
 one_par <- function(model) {
   tryCatch(
     {
