@@ -13,14 +13,18 @@ string_ends_with <- function(pattern, x) {
   grep(pattern, x, perl = TRUE)
 }
 
-#' @importFrom purrr map
 string_one_of <- function(pattern, x) {
   m <- unlist(purrr::map(pattern, ~ grep(., x, fixed = TRUE, useBytes = TRUE)))
   x[m]
 }
 
-rownames_as_column <- function(x, var = "rowname") {
-  rn <- data.frame(rn = rownames(x), stringsAsFactors = FALSE)
+rownames_as_column <- function(x, var = "rowname", rownames = NULL) {
+  if (is.null(rownames)) {
+    rn <- rownames(x)
+  } else {
+    rn <- rownames
+  }
+  rn <- data.frame(rn = rn, stringsAsFactors = FALSE)
   x <- cbind(rn, x)
   colnames(x)[1] <- var
   rownames(x) <- NULL
@@ -35,26 +39,24 @@ obj_has_rownames <- function(x) {
   !identical(as.character(1:nrow(x)), rownames(x))
 }
 
-#' @importFrom dplyr select
-add_cases <- function(data, ..., .after = -1, .before = NULL) {
 
-  dat <- data.frame(..., stringsAsFactors = FALSE)
-  x <- rbind(data, NA)
-  last.row <- nrow(x)
 
-  if (!is.null(.before))
-    .after <- .before - 1
+#' @keywords internal
+.gather <- function(x, names_to = "key", values_to = "value", columns = colnames(x)) {
+  if (is.numeric(columns)) columns <- colnames(x)[columns]
+  dat <- stats::reshape(
+    x,
+    idvar = "id",
+    ids = row.names(x),
+    times = columns,
+    timevar = names_to,
+    v.names = values_to,
+    varying = list(columns),
+    direction = "long"
+  )
 
-  for (.x in colnames(dat)) {
-    x[last.row, .x] <- dat[[.x]]
-  }
+  if (is.factor(dat[[values_to]]))
+    dat[[values_to]] <- as.character(dat[[values_to]])
 
-  if (.after < 1)
-    o <- c(last.row, 1:(last.row - 1))
-  else if (is.infinite(.after))
-    o <- 1:last.row
-  else
-    o <- c(1:.after, last.row, (.after + 1):(last.row - 1))
-
-  x[o, , drop = FALSE]
+  dat[, 1:(ncol(dat) - 1), drop = FALSE]
 }
