@@ -57,6 +57,7 @@
 #'
 #' @examples
 #' # prepare data
+#' if (requireNamespace("haven")) {
 #' library(sjmisc)
 #' data(efc)
 #' efc <- to_factor(efc, c161sex, e42dep, c172code)
@@ -79,21 +80,21 @@
 #'
 #' # get colour values from specific palette
 #' sjplot_pal(pal = "breakfast club")
+#' }
 #'
-#' @import ggplot2
 #' @rdname sjPlot-themes
 #' @export
 theme_sjplot <- function(base_size = 12, base_family = "") {
-  (theme_minimal(base_size = base_size, base_family = base_family) +
-     theme(
-       axis.line.x      = element_line(colour = "grey80"),
-       axis.line.y      = element_line(colour = "grey80"),
-       axis.text        = element_text(colour = "grey50"),
-       axis.title       = element_text(colour = "grey30"),
-       strip.background = element_rect(colour = "grey70", fill = "grey90"),
-       strip.text       = element_text(colour = "grey30"),
-       legend.title     = element_text(colour = "grey30"),
-       legend.text      = element_text(colour = "grey30")
+  (ggplot2::theme_minimal(base_size = base_size, base_family = base_family) +
+     ggplot2::theme(
+       axis.line.x      = ggplot2::element_line(colour = "grey80"),
+       axis.line.y      = ggplot2::element_line(colour = "grey80"),
+       axis.text        = ggplot2::element_text(colour = "grey50"),
+       axis.title       = ggplot2::element_text(colour = "grey30"),
+       strip.background = ggplot2::element_rect(colour = "grey70", fill = "grey90"),
+       strip.text       = ggplot2::element_text(colour = "grey30"),
+       legend.title     = ggplot2::element_text(colour = "grey30"),
+       legend.text      = ggplot2::element_text(colour = "grey30")
      ))
 }
 
@@ -101,16 +102,16 @@ theme_sjplot <- function(base_size = 12, base_family = "") {
 #' @rdname sjPlot-themes
 #' @export
 theme_sjplot2 <- function(base_size = 12, base_family = "") {
-  (theme_minimal(base_size = base_size, base_family = base_family) +
-     theme(
-       axis.line.x      = element_line(colour = "grey50"),
-       axis.line.y      = element_line(colour = "grey50"),
-       axis.text        = element_text(colour = "grey10"),
-       axis.title       = element_text(colour = "black"),
-       strip.background = element_rect(colour = "grey50", fill = "grey70"),
-       strip.text       = element_text(colour = "grey20"),
-       legend.title     = element_text(colour = "grey10"),
-       legend.text      = element_text(colour = "grey20")
+  (ggplot2::theme_minimal(base_size = base_size, base_family = base_family) +
+     ggplot2::theme(
+       axis.line.x      = ggplot2::element_line(colour = "grey50"),
+       axis.line.y      = ggplot2::element_line(colour = "grey50"),
+       axis.text        = ggplot2::element_text(colour = "grey10"),
+       axis.title       = ggplot2::element_text(colour = "black"),
+       strip.background = ggplot2::element_rect(colour = "grey50", fill = "grey70"),
+       strip.text       = ggplot2::element_text(colour = "grey20"),
+       legend.title     = ggplot2::element_text(colour = "grey10"),
+       legend.text      = ggplot2::element_text(colour = "grey20")
      ))
 }
 
@@ -118,14 +119,14 @@ theme_sjplot2 <- function(base_size = 12, base_family = "") {
 #' @rdname sjPlot-themes
 #' @export
 theme_blank <- function(base_size = 12, base_family = "") {
-  (theme_minimal(base_size = base_size, base_family = base_family) +
-     theme(
-       axis.line.x      = element_line(colour = "white"),
-       axis.line.y      = element_line(colour = "white"),
-       axis.text        = element_text(colour = "grey50"),
-       axis.title       = element_text(colour = "grey30"),
-       panel.grid.minor = element_line(colour = "white", linetype = 1),
-       panel.grid.major = element_line(colour = "white", linetype = 1)
+  (ggplot2::theme_minimal(base_size = base_size, base_family = base_family) +
+     ggplot2::theme(
+       axis.line.x      = ggplot2::element_line(colour = "white"),
+       axis.line.y      = ggplot2::element_line(colour = "white"),
+       axis.text        = ggplot2::element_text(colour = "grey50"),
+       axis.title       = ggplot2::element_text(colour = "grey30"),
+       panel.grid.minor = ggplot2::element_line(colour = "white", linetype = 1),
+       panel.grid.major = ggplot2::element_line(colour = "white", linetype = 1)
      ))
 }
 
@@ -133,63 +134,73 @@ theme_blank <- function(base_size = 12, base_family = "") {
 #' @rdname sjPlot-themes
 #' @export
 theme_538 <- function(base_size = 12, base_family = "") {
-  (theme_minimal(base_size = base_size, base_family = base_family) +
-     theme(
-       axis.line.x        = element_line(colour = "#F0F0F0"),
-       axis.line.y        = element_line(colour = "#F0F0F0"),
-       axis.text          = element_text(colour = "#737373"),
-       axis.title         = element_text(colour = "#525252"),
-       plot.background    = element_rect(colour = "#F0F0F0", fill = "#F0F0F0"),
-       panel.grid.minor.x = element_line(colour = "#F0F0F0", linetype = 1),
-       panel.grid.major   = element_line(colour = "#BDBDBD", linetype = 1),
-       panel.grid.major.y = element_line(colour = "#F0F0F0", linetype = 1),
-       panel.grid.minor.y = element_line(colour = "#F0F0F0", linetype = 1)
+  (ggplot2::theme_minimal(base_size = base_size, base_family = base_family) +
+     ggplot2::theme(
+       axis.line.x        = ggplot2::element_line(colour = "#F0F0F0"),
+       axis.line.y        = ggplot2::element_line(colour = "#F0F0F0"),
+       axis.text          = ggplot2::element_text(colour = "#737373"),
+       axis.title         = ggplot2::element_text(colour = "#525252"),
+       plot.background    = ggplot2::element_rect(colour = "#F0F0F0", fill = "#F0F0F0"),
+       panel.grid.minor.x = ggplot2::element_line(colour = "#F0F0F0", linetype = 1),
+       panel.grid.major   = ggplot2::element_line(colour = "#BDBDBD", linetype = 1),
+       panel.grid.major.y = ggplot2::element_line(colour = "#F0F0F0", linetype = 1),
+       panel.grid.minor.y = ggplot2::element_line(colour = "#F0F0F0", linetype = 1)
      ))
 }
 
 
 #' @rdname sjPlot-themes
 #' @export
-font_size <- function(title, axis_title.x, axis_title.y, labels.x, labels.y, offset.x, offset.y, base.theme) {
+font_size <- function(
+  title,
+  axis_title.x,
+  axis_title.y,
+  labels.x,
+  labels.y,
+  offset.x,
+  offset.y,
+  base.theme
+) {
   # get current theme
-  if (!missing(base.theme))
+  if (!missing(base.theme)) {
     cur.theme <- base.theme
-  else
-    cur.theme <- theme_get()
+  } else {
+    cur.theme <- ggplot2::theme_get()
+  }
 
   if (!missing(title)) {
     cur.theme <- cur.theme +
-      theme(title = element_text(size = title))
+      ggplot2::theme(title = ggplot2::element_text(size = title))
   }
 
   if (!missing(axis_title.x)) {
     cur.theme <- cur.theme +
-      theme(axis.title.x = element_text(size = axis_title.x))
+      ggplot2::theme(axis.title.x = ggplot2::element_text(size = axis_title.x))
   }
 
   if (!missing(axis_title.y)) {
     cur.theme <- cur.theme +
-      theme(axis.title.y = element_text(size = axis_title.y))
+      ggplot2::theme(axis.title.y = ggplot2::element_text(size = axis_title.y))
   }
 
   if (!missing(labels.x)) {
     cur.theme <- cur.theme +
-      theme(axis.text.x =  element_text(size = labels.x))
+      ggplot2::theme(axis.text.x = ggplot2::element_text(size = labels.x))
   }
 
   if (!missing(labels.y)) {
     cur.theme <- cur.theme +
-      theme(axis.text.y =  element_text(size = labels.y))
+      ggplot2::theme(axis.text.y = ggplot2::element_text(size = labels.y))
   }
 
   if (!missing(offset.x)) {
     cur.theme <- cur.theme +
-      theme(axis.title.x = element_text(vjust = offset.x))
+      ggplot2::theme(axis.title.x = ggplot2::element_text(vjust = offset.x))
   }
 
   if (!missing(offset.y)) {
     cur.theme <- cur.theme +
-      theme(axis.title.y = element_text(vjust = offset.y))
+      ggplot2::theme(axis.title.y = ggplot2::element_text(vjust = offset.y))
   }
 
   cur.theme
@@ -200,19 +211,20 @@ font_size <- function(title, axis_title.x, axis_title.y, labels.x, labels.y, off
 #' @export
 label_angle <- function(angle.x, angle.y, base.theme) {
   # get current theme
-  if (!missing(base.theme))
+  if (!missing(base.theme)) {
     cur.theme <- base.theme
-  else
-    cur.theme <- theme_get()
+  } else {
+    cur.theme <- ggplot2::theme_get()
+  }
 
   if (!missing(angle.x)) {
     cur.theme <- cur.theme +
-      theme(axis.text.x = element_text(angle = angle.x))
+      ggplot2::theme(axis.text.x = ggplot2::element_text(angle = angle.x))
   }
 
   if (!missing(angle.y)) {
     cur.theme <- cur.theme +
-      theme(axis.text.y = element_text(angle = angle.y))
+      ggplot2::theme(axis.text.y = ggplot2::element_text(angle = angle.y))
   }
 
   cur.theme
@@ -220,14 +232,14 @@ label_angle <- function(angle.x, angle.y, base.theme) {
 
 
 #' @rdname sjPlot-themes
-#' @importFrom dplyr case_when
 #' @export
 legend_style <- function(inside, pos, justify, base.theme) {
   # get current theme
-  if (!missing(base.theme))
+  if (!missing(base.theme)) {
     cur.theme <- base.theme
-  else
-    cur.theme <- theme_get()
+  } else {
+    cur.theme <- ggplot2::theme_get()
+  }
 
   # convert legend position from character to numeric index
   if (!missing(inside) && inside) {
@@ -245,11 +257,13 @@ legend_style <- function(inside, pos, justify, base.theme) {
   }
 
   # set default justification
-  if (missing(justify)) justify <- "center"
+  if (missing(justify)) {
+    justify <- "center"
+  }
 
   if (!missing(pos)) {
     cur.theme <- cur.theme +
-      theme(
+      ggplot2::theme(
         legend.position = pos,
         legend.justification = justify
       )
@@ -260,73 +274,79 @@ legend_style <- function(inside, pos, justify, base.theme) {
 
 
 sjplot_colors <- list(
-  `aqua` = c("#BAF5F3", "#46A9BE", "#8B7B88", "#BD7688", "#F2C29E", "#BAF5F3", "#46A9BE", "#8B7B88"),
-  `warm` = c("#F8EB85", "#F1B749", "#C45B46", "#664458", "#072835", "#F8EB85", "#F1B749", "#C45B46"),
-  `dust` = c("#AAAE9D", "#F8F7CF", "#F7B98B", "#7B5756", "#232126", "#AAAE9D", "#F8F7CF", "#F7B98B"),
-  `blambus` = c("#5D8191", "#F2DD26", "#494949", "#BD772D", "#E02E1F", "#5D8191", "#F2DD26", "#494949"),
-  `simply` = c("#CD423F", "#FCDA3B", "#0171D3", "#018F77", "#F5C6AC", "#CD423F", "#FCDA3B", "#0171D3"),
-  `us` = c("#004D80", "#376C8E", "#37848E", "#9BC2B6", "#B5D2C0", "#004D80", "#376C8E", "#37848E"),
-  `deep reefs` = c("#43a9b6", "#218282", "#dbdcd1", "#44515c", "#517784"),
-  `breakfast club` = c("#b6411a", "#eec3d8", "#4182dd", "#ecf0c8", "#2d6328"),
-  `metro ui` = c("#d11141", "#00aedb", "#00b159", "#f37735", "#8c8c8c", "#ffc425", "#cccccc"),
+  `aqua` = c("#BAF5F3", "#46A9BE", "#8B7B88", "#BD7688", "#F2C29E"),
+  `warm` = c("#072835", "#664458", "#C45B46", "#F1B749", "#F8EB85"),
+  `dust` = c("#232126", "#7B5756", "#F7B98B", "#F8F7CF", "#AAAE9D"),
+  `blambus` = c("#E02E1F", "#5D8191", "#BD772D", "#494949", "#F2DD26"),
+  `simply` = c("#CD423F", "#0171D3", "#018F77", "#FCDA3B", "#F5C6AC"),
+  `us` = c("#004D80", "#376C8E", "#37848E", "#9BC2B6", "#B5D2C0"),
+  `reefs` = c("#43a9b6", "#218282", "#dbdcd1", "#44515c", "#517784"),
+  `breakfast club` = c("#b6411a", "#4182dd", "#2d6328", "#eec3d8", "#ecf0c8"),
+  `metro` = c("#d11141", "#00aedb", "#00b159", "#f37735", "#8c8c8c", "#ffc425", "#cccccc"),
   `viridis` = c("#440154", "#46337E", "#365C8D", "#277F8E", "#1FA187", "#4AC16D", "#9FDA3A", "#FDE725"),
-  `ipsum` = c("#d18975", "#8fd175", "#3f2d54", "#75b8d1", "#2d543d", "#c9d175", "#d1ab75", "#d175b8", "#758bd1"),
+  `ipsum` = c("#3f2d54", "#75b8d1", "#2d543d", "#d18975", "#8fd175", "#d175b8", "#758bd1", "#d1ab75", "#c9d175"),
   `quadro` = c("#ff0000", "#1f3c88", "#23a393", "#f79f24", "#625757"),
   `eight` = c("#003f5c", "#2f4b7c", "#665191", "#a05195", "#d45087", "#f95d6a", "#ff7c43", "#ffa600"),
-  `circus` = c("#0664C9", "#C1241E", "#EBD90A", "#6F130D", "#111A79"),
+  `circus` = c("#C1241E", "#0664C9", "#EBD90A", "#6F130D", "#111A79"),
   `system` = c("#0F2838", "#F96207", "#0DB0F3", "#04EC04", "#FCC44C"),
   `hero` = c("#D2292B", "#165E88", "#E0BD1C", "#D57028", "#A5CB39", "#8D8F70"),
-  `flat` = c("#2980b9", "#c0392b", "#16a085", "#f39c12", "#8e44ad", "#7f8c8d", "#d35400"),
-  `social` = c("#0077B5", "#b92b27", "#00b489", "#f57d00", "#410093", "#21759b", "#ff3300")
+  `flat` = c("#c0392b", "#2980b9", "#16a085", "#f39c12", "#8e44ad", "#7f8c8d", "#d35400"),
+  `social` = c("#b92b27", "#0077B5", "#00b489", "#f57d00", "#410093", "#21759b", "#ff3300")
 )
 
 
 #' @rdname sjPlot-themes
 #' @export
-scale_color_sjplot <- function(palette = "metro ui", discrete = TRUE, reverse = FALSE, ...) {
+scale_color_sjplot <- function(palette = "metro", discrete = TRUE, reverse = FALSE, ...) {
   pal <- get_sjplot_pal(palette = palette, reverse = reverse)
 
   if (discrete) {
-    discrete_scale("colour", paste0("sjplot_pal_", palette), palette = pal, ...)
+    ggplot2::discrete_scale("colour", paste0("sjplot_pal_", palette), palette = pal, ...)
   } else {
-    scale_color_gradientn(colours = pal(256), ...)
+    ggplot2::scale_color_gradientn(colours = pal(256), ...)
   }
 }
 
 
 #' @rdname sjPlot-themes
 #' @export
-scale_fill_sjplot <- function(palette = "metro ui", discrete = TRUE, reverse = FALSE, ...) {
+scale_fill_sjplot <- function(palette = "metro", discrete = TRUE, reverse = FALSE, ...) {
   pal <- get_sjplot_pal(palette = palette, reverse = reverse)
 
   if (discrete) {
-    discrete_scale("fill", paste0("sjplot_pal_", palette), palette = pal, ...)
+    ggplot2::discrete_scale("fill", paste0("sjplot_pal_", palette), palette = pal, ...)
   } else {
-    scale_fill_gradientn(colours = pal(256), ...)
+    ggplot2::scale_fill_gradientn(colours = pal(256), ...)
   }
 }
 
 
 #' @rdname sjPlot-themes
 #' @export
-sjplot_pal <- function(palette = "metro ui", n = NULL) {
+sjplot_pal <- function(palette = "metro", n = NULL) {
   pl <- sjplot_colors[[palette]]
 
-  if (!is.null(n) && n <= length(pl))
-    pl <- pl[1:n]
+  if (!is.null(n) && n <= length(pl)) {
+    if (.is_cont_scale(palette)) {
+      pl <- pl[stats::quantile(1:length(pl), probs = seq(0, 1, length.out = n))]
+    } else {
+      pl <- pl[1:n]
+    }
+  }
 
   pl
 }
 
+# palettes with a continuous color scale
+.is_cont_scale <- function(p) {
+  p %in% c("aqua", "dust", "eight", "greyscale", "us", "viridis", "warm")
+}
+
 
 #' @rdname sjPlot-themes
-#' @importFrom purrr map_df
-#' @importFrom tidyr gather
-#' @importFrom dplyr arrange mutate
 #' @importFrom rlang .data
 #' @export
 show_sjplot_pals <- function() {
-
   longest.pal <- max(purrr::map_dbl(sjplot_colors, ~ length(.x)))
 
   sjpc <- lapply(sjplot_colors, function(.x) {
@@ -337,31 +357,35 @@ show_sjplot_pals <- function() {
   })
 
   x <- suppressWarnings(
-    sjpc %>%
-      as.data.frame() %>%
-      purrr::map_df(~ .x[length(.x):1]) %>%
-      tidyr::gather() %>%
+    sjpc |>
+      as.data.frame() |>
+      purrr::map_df(~ .x[length(.x):1]) |>
+      tidyr::gather() |>
       dplyr::arrange(.data$key)
   )
 
   x$y <- rep_len(1:longest.pal, nrow(x))
   x$cols = as.factor(1:nrow(x))
 
-  x$key <- rev(x$key)
-  ggplot(x, aes_string(x = "key", fill = "cols")) +
-    geom_bar(width = .7) +
-    scale_fill_manual(values = x$value) +
-    scale_x_discrete(labels = rev(sort(names(sjpc)))) +
-    scale_y_continuous(breaks = NULL, labels = NULL) +
-    guides(fill = "none") +
-    coord_flip() +
-    theme_minimal() +
-    labs(x = NULL, y = NULL)
+  x$key <- factor(x$key, levels = rev(unique(x$key)))
+
+  x$group <- "Other Palettes"
+  x$group[.is_cont_scale(x$key)] <- "Continuous Palettes"
+  x$group[x$key %in% c("breakfast.club", "flat", "metro", "quadro", "set1", "simply", "social")] <- "Red-Blue-Green Palettes"
+
+  ggplot2::ggplot(x, ggplot2::aes(x = .data$key, fill = .data$cols)) +
+    ggplot2::geom_bar(width = .7) +
+    ggplot2::scale_fill_manual(values = x$value) +
+    ggplot2::scale_y_continuous(breaks = NULL, labels = NULL) +
+    ggplot2::guides(fill = "none") +
+    ggplot2::coord_flip() +
+    ggplot2::theme_minimal() +
+    ggplot2::labs(x = NULL, y = NULL) +
+    ggplot2::facet_wrap(~group, ncol = 1, scales = "free")
 }
 
 
-#' @importFrom grDevices colorRampPalette
-get_sjplot_pal <- function(palette = "metro ui", reverse = FALSE, ...) {
+get_sjplot_pal <- function(palette = "metro", reverse = FALSE, ...) {
   pal <- sjplot_colors[[palette]]
   if (reverse) pal <- rev(pal)
   grDevices::colorRampPalette(pal, ...)
@@ -390,5 +414,8 @@ css.themes <- list(
   `cells` = list(
     css.td = "border:1px solid black;",
     css.thead = "border:1px solid black;"
+  ),
+  `right_aligned` = list(
+    css.tdata = "padding:0.2cm; text-align:right; vertical-align:middle;"
   )
 )
