@@ -85,10 +85,10 @@
 #'              \item Jorion N, Self B, James K, Schroeder L, DiBello L, Pellegrino J (2013) Classical Test Theory Analysis of the Dynamics Concept Inventory. (\href{https://www.academia.edu/4104752/Classical_Test_Theory_Analysis_of_the_Dynamics_Concept_Inventory}{web})
 #'              \item Briggs SR, Cheek JM (1986) The role of factor analysis in the development and evaluation of personality scales. Journal of Personality, 54(1), 106-148. doi: 10.1111/j.1467-6494.1986.tb00391.x
 #'              \item McLean S et al. (2013) Stigmatizing attitudes and beliefs about bulimia nervosa: Gender, age, education and income variability in a community sample. International Journal of Eating Disorders. doi: 10.1002/eat.22227
-#'              \item Trochim WMK (2008) Types of Reliability. (\href{http://www.socialresearchmethods.net/kb/reltypes.php}{web})
+#'              \item Trochim WMK (2008) Types of Reliability.
 #'             }
 #'
-#' @examples
+#' @examplesIf insight::check_if_installed("performance", minimum_version = "0.14.1", quietly = TRUE)
 #' # Data from the EUROFAMCARE sample dataset
 #' library(sjmisc)
 #' library(sjlabelled)
@@ -121,12 +121,6 @@
 #'   # or, equivalent
 #'   tab_itemscale(mydf, factor.groups = "auto")
 #' }}
-#' @importFrom stats shapiro.test na.omit
-#' @importFrom sjstats mean_n
-#' @importFrom performance item_reliability cronbachs_alpha item_intercor
-#' @importFrom parameters principal_components kurtosis closest_component
-#' @importFrom sjmisc std descr
-#' @importFrom sjlabelled set_label
 #' @export
 tab_itemscale <- function(df,
                              factor.groups = NULL,
@@ -215,7 +209,7 @@ tab_itemscale <- function(df,
 
     # ideal item difficulty
     fun.diff.ideal <- function(x) {
-      p <- 1 / max(x, na.rm = T)
+      p <- 1 / max(x, na.rm = TRUE)
       round(p + (1 - p) / 2, 2)
     }
 
@@ -226,7 +220,7 @@ tab_itemscale <- function(df,
     reli <- performance::item_reliability(df.sub, standardize = scale)
 
     # get index score value, by retrieving the row mean
-    item.score <- sjstats::mean_n(df.sub, min.valid.rowmean)
+    item.score <- datawizard::row_means(df.sub, min_valid = min.valid.rowmean)
 
     # store scaled values of each item's total score
     # to compute correlation coefficients between identified components
@@ -236,8 +230,8 @@ tab_itemscale <- function(df,
     # check if we have valid return values from reliability test.
     # In case df had less than 3 columns, NULL is returned
     if (!is.null(reli)) {
-      alpha <- reli$alpha_if_deleted
-      itemdis <- reli$item_discrimination
+      alpha <- reli$Alpha_if_deleted
+      itemdis <- reli$Discrimination
     } else {
       alpha <- as.factor(NA)
       itemdis <- as.factor(NA)
@@ -255,7 +249,7 @@ tab_itemscale <- function(df,
 
     # include kurtosis statistics
     if (show.kurtosis) {
-      df.dummy <- data_frame(cbind(df.dummy, round(as.numeric(parameters::kurtosis(df.sub)), 2)))
+      df.dummy <- data_frame(cbind(df.dummy, round(as.numeric(datawizard::kurtosis(df.sub)), 2)))
       df.colnames <- c(df.colnames, "Kurtosis")
     }
 
