@@ -71,7 +71,7 @@
 #' @param show.p Logical, if \code{TRUE}, p-values are also printed.
 #' @param show.se Logical, if \code{TRUE}, the standard errors are
 #'   also printed. If robust standard errors are required, use arguments
-#'   \code{vcov.fun}, \code{vcov.type} and \code{vcov.args} (see
+#'   \code{vcov.fun}, and \code{vcov.args} (see
 #'   \code{\link[parameters]{standard_error}} for details).
 #' @param show.r2 Logical, if \code{TRUE}, the r-squared value is also printed.
 #'    Depending on the model, these might be pseudo-r-squared values, or Bayesian
@@ -92,7 +92,7 @@
 #' @param string.se Character vector, used for the column heading of standard error values. Default is \code{"std. Error"}.
 #' @param string.std_se Character vector, used for the column heading of standard error of standardized coefficients. Default is \code{"standardized std. Error"}.
 #' @param string.std_ci Character vector, used for the column heading of confidence intervals of standardized coefficients. Default is \code{"standardized std. Error"}.
-#' @param string.p Character vector, used for the column heading of p values. Default is \code{"p"}.
+#' @param string.p String value, used for the column heading of p values. Default is \code{"p"}.
 #' @param string.std.p Character vector, used for the column heading of p values. Default is \code{"std. p"}.
 #' @param string.df Character vector, used for the column heading of degrees of freedom. Default is \code{"df"}.
 #' @param string.stat Character vector, used for the test statistic. Default is \code{"Statistic"}.
@@ -196,16 +196,15 @@
 #'   Default standardization is done by completely refitting the model on the
 #'   standardized data. Hence, this approach is equal to standardizing the
 #'   variables before fitting the model, which is particularly recommended for
-#'   complex models that include interactions or transformations (e.g., polynomial
-#'   or spline terms). When \code{show.std = "std2"}, standardization of estimates
-#'   follows \href{http://www.stat.columbia.edu/~gelman/research/published/standardizing7.pdf}{Gelman's (2008)}
-#'   suggestion, rescaling the estimates by dividing them by two standard deviations
-#'   instead of just one. Resulting coefficients are then directly comparable for
-#'   untransformed binary predictors. For backward compatibility reasons,
-#'   \code{show.std} also may be a logical value; if \code{TRUE}, normal standardized
-#'   estimates are printed (same effect as \code{show.std = "std"}). Use
-#'   \code{show.std = NULL} (default) or \code{show.std = FALSE}, if no standardization
-#'   is required.
+#'   complex models that include interactions or transformations (e.g.,
+#'   polynomial or spline terms). When \code{show.std = "std2"}, standardization
+#'   of estimates follows Gelman's (2008) suggestion, rescaling the estimates by
+#'   dividing them by two standard deviations instead of just one. Resulting
+#'   coefficients are then directly comparable for untransformed binary
+#'   predictors. For backward compatibility reasons, \code{show.std} also may be
+#'   a logical value; if \code{TRUE}, normal standardized estimates are printed
+#'   (same effect as \code{show.std = "std"}). Use \code{show.std = NULL}
+#'   (default) or \code{show.std = FALSE}, if no standardization is required.
 #' }
 #' \subsection{How do I use \code{CSS}-argument?}{
 #'    With the \code{CSS}-argument, the visual appearance of the tables
@@ -240,6 +239,7 @@ tab_model <- function(
   show.ci50 = FALSE,
   show.se = NULL,
   show.std = NULL,
+  std.response = TRUE,
   show.p = TRUE,
   show.stat = FALSE,
   show.df = FALSE,
@@ -272,9 +272,7 @@ tab_model <- function(
   iterations = 1000,
   seed = NULL,
 
-  robust = FALSE,
   vcov.fun = NULL,
-  vcov.type = NULL,
   vcov.args = NULL,
 
   string.pred = "Predictors",
@@ -361,11 +359,6 @@ tab_model <- function(
 
   if (p.style == "stars") show.p <- FALSE
 
-  # default robust?
-  if (isTRUE(robust)) {
-    vcov.fun <- "HC3"
-  }
-
   models <- list(...)
 
   if (length(class(models[[1]])) == 1 && inherits(models[[1]], "list"))
@@ -457,7 +450,7 @@ tab_model <- function(
         tf = transform,
         type = "est",
         bpe = bpe,
-        robust = list(vcov.fun = vcov.fun, vcov.type = vcov.type, vcov.args = vcov.args),
+        robust = list(vcov.fun = vcov.fun, vcov.args = vcov.args),
         facets = FALSE,
         show.zeroinf = show.zeroinf,
         p.val = p.val,
@@ -484,7 +477,7 @@ tab_model <- function(
       # merge CI columns
 
       if (all(c("conf.low", "conf.high") %in% names(dat))) {
-        dat <- dat %>%
+        dat <- dat |>
           dplyr::mutate(conf.int = sprintf(
             "%.*f%s%.*f",
             digits,
@@ -492,15 +485,15 @@ tab_model <- function(
             ci.hyphen,
             digits,
             .data$conf.high
-          )) %>%
+          )) |>
           dplyr::select(-.data$conf.low, -.data$conf.high)
       }
 
       # get inner probability (i.e. 2nd CI for Stan-models) ----
 
       if (is.stan(model)) {
-        dat <- dat %>%
-          sjmisc::var_rename(conf.int = "ci.outer") %>%
+        dat <- dat |>
+          sjmisc::var_rename(conf.int = "ci.outer") |>
           dplyr::mutate(ci.inner = sprintf(
             "%.*f%s%.*f",
             digits,
@@ -508,7 +501,7 @@ tab_model <- function(
             ci.hyphen,
             digits,
             .data$conf.high50
-          )) %>%
+          )) |>
             dplyr::select(-.data$conf.low50, -.data$conf.high50)
       }
 
@@ -522,7 +515,7 @@ tab_model <- function(
           tf = transform,
           type = "est",
           bpe = bpe,
-          robust = list(vcov.fun = vcov.fun, vcov.type = vcov.type, vcov.args = vcov.args),
+          robust = list(vcov.fun = vcov.fun, vcov.args = vcov.args),
           facets = FALSE,
           show.zeroinf = show.zeroinf,
           p.val = p.val,
@@ -532,9 +525,10 @@ tab_model <- function(
           iterations = iterations,
           seed = seed,
           keep = keep,
-          drop = drop
-        ) %>%
-          format_p_values(p.style, digits.p, emph.p, p.threshold) %>%
+          drop = drop,
+          std.response = std.response
+        ) |>
+          format_p_values(p.style, digits.p, emph.p, p.threshold) |>
           sjmisc::var_rename(
             estimate = "std.estimate",
             std.error = "std.se",
@@ -543,7 +537,7 @@ tab_model <- function(
             p.value = "std.p.value",
             statistic = "std.statistic",
             p.stars = "std.p.stars"
-          ) %>%
+          ) |>
           dplyr::select(-1)
 
         # transform estimates
@@ -556,8 +550,8 @@ tab_model <- function(
           tmp_dat[["std.se"]] <- tmp_dat[["std.se"]] * tmp_dat[["std.estimate"]]
         }
 
-        dat <- tmp_dat %>%
-          sjmisc::add_columns(dat) %>%
+        dat <- tmp_dat |>
+          sjmisc::add_columns(dat) |>
           dplyr::mutate(std.conf.int = sprintf(
             "%.*f%s%.*f",
             digits,
@@ -565,12 +559,12 @@ tab_model <- function(
             ci.hyphen,
             digits,
             .data$std.conf.high
-          )) %>%
+          )) |>
           dplyr::select(-.data$std.conf.low, -.data$std.conf.high)
         # if t-statistic is the same for standardized and unstandardized model
         # remove standardized; ignore intercept
         if (all(round(dat$statistic[-1], 3) == round(dat$std.statistic[-1], 3))) {
-          dat <- dat %>%
+          dat <- dat |>
             dplyr::select(-.data$std.statistic, -.data$std.p.value)
         }
       }
@@ -607,8 +601,8 @@ tab_model <- function(
 
       # for HTML, convert numerics to character ----
 
-      dat <- dat %>%
-        purrr::map_if(is.numeric, ~ sprintf("%.*f", digits, .x)) %>%
+      dat <- dat |>
+        purrr::map_if(is.numeric, ~ sprintf("%.*f", digits, .x)) |>
         as.data.frame(stringsAsFactors = FALSE)
 
 
@@ -682,8 +676,8 @@ tab_model <- function(
         zi <- which(dat[[wf]] %in% c("Zero-Inflated Model", "Zero Inflation Model", "zero_inflated", "zi"))
 
         if (show.zeroinf && !sjmisc::is_empty(zi)) {
-          zidat <- dat %>%
-            dplyr::slice(!! zi) %>%
+          zidat <- dat |>
+            dplyr::slice(!! zi) |>
             dplyr::select(!! -wf)
         }
 
@@ -794,7 +788,7 @@ tab_model <- function(
       n_re_grps <- NULL
 
       if (show.ngroups && is_mixed_model(model)) {
-        rand_eff <- insight::get_data(model)[, insight::find_random(model, split_nested = TRUE, flatten = TRUE), drop = FALSE]
+        rand_eff <- insight::get_data(model, verbose = FALSE)[, insight::find_random(model, split_nested = TRUE, flatten = TRUE), drop = FALSE]
         n_re_grps <- sapply(rand_eff, function(.i) length(unique(.i, na.rm = TRUE)))
         names(n_re_grps) <- sprintf("ngrps.%s", names(n_re_grps))
       }
@@ -951,8 +945,8 @@ tab_model <- function(
 
   # Join all models into one data frame, and replace NA by empty strings
 
-  dat <- model.data %>%
-    purrr::reduce(~ dplyr::full_join(.x, .y, by = "term")) %>%
+  dat <- model.data |>
+    purrr::reduce(~ dplyr::full_join(.x, .y, by = "term")) |>
     purrr::map_df(~ dplyr::if_else(.x %in% na.vals | is.na(.x), "", .x))
 
   # remove unwanted columns and rows ----
@@ -978,8 +972,8 @@ tab_model <- function(
 
   zeroinf <- NULL
   if (!sjmisc::is_empty(zeroinf.data)) {
-    zeroinf <- zeroinf.data %>%
-      purrr::reduce(~ dplyr::full_join(.x, .y, by = "term")) %>%
+    zeroinf <- zeroinf.data |>
+      purrr::reduce(~ dplyr::full_join(.x, .y, by = "term")) |>
       purrr::map_df(~ dplyr::if_else(.x %in% na.vals | is.na(.x), "", .x))
 
     zeroinf <-
@@ -1125,7 +1119,7 @@ tab_model <- function(
       linesep = "<br>"
     )
   } else if (is.null(dv.labels)) {
-    dv.labels <- purrr::map(models, insight::find_response) %>% purrr::flatten_chr()
+    dv.labels <- purrr::map(models, insight::find_response) |> purrr::flatten_chr()
   }
 
 
@@ -1266,7 +1260,6 @@ tab_model <- function(
 }
 
 
-#' @importFrom stats na.omit
 sort_columns <- function(x, is.stan, col.order) {
   ## TODO check code for multiple response models
   ## TODO allow custom sorting
@@ -1303,19 +1296,20 @@ sort_columns <- function(x, is.stan, col.order) {
 }
 
 
-#' @importFrom dplyr select slice
-remove_unwanted <- function(dat,
-                            show.intercept,
-                            show.est,
-                            show.std,
-                            show.ci,
-                            show.se,
-                            show.stat,
-                            show.p,
-                            show.df,
-                            show.response,
-                            terms,
-                            rm.terms) {
+remove_unwanted <- function(
+  dat,
+  show.intercept,
+  show.est,
+  show.std,
+  show.ci,
+  show.se,
+  show.stat,
+  show.p,
+  show.df,
+  show.response,
+  terms,
+  rm.terms
+) {
   if (!show.intercept) {
     ints1 <- string_contains("(Intercept", x = dat$term)
     ints2 <- string_contains("b_Intercept", x = dat$term)
@@ -1324,8 +1318,9 @@ remove_unwanted <- function(dat,
 
     ints <- c(ints1, ints2, ints3, ints4)
 
-    if (!sjmisc::is_empty(ints))
-      dat <- dplyr::slice(dat, !! -ints)
+    if (!sjmisc::is_empty(ints)) {
+      dat <- dplyr::slice(dat, !!-ints)
+    }
   }
 
   if (show.est == FALSE) {
@@ -1338,7 +1333,10 @@ remove_unwanted <- function(dat,
   }
 
   if (is.null(show.std) || show.std == FALSE) {
-    dat <- dplyr::select(dat, -string_starts_with("std.estimate", x = colnames(dat)))
+    dat <- dplyr::select(
+      dat,
+      -string_starts_with("std.estimate", x = colnames(dat))
+    )
   }
 
   if (is.null(show.ci) || show.ci == FALSE) {
@@ -1359,17 +1357,26 @@ remove_unwanted <- function(dat,
   }
 
   if (show.stat == FALSE) {
-    dat <- dplyr::select(dat, -string_starts_with("statistic", x = colnames(dat)),
-                         -string_starts_with("std.statistic", x = colnames(dat)))
+    dat <- dplyr::select(
+      dat,
+      -string_starts_with("statistic", x = colnames(dat)),
+      -string_starts_with("std.statistic", x = colnames(dat))
+    )
   }
 
   if (show.response == FALSE) {
-    dat <- dplyr::select(dat, -string_starts_with("response.level", x = colnames(dat)))
+    dat <- dplyr::select(
+      dat,
+      -string_starts_with("response.level", x = colnames(dat))
+    )
   }
 
   if (show.p == FALSE) {
-    dat <- dplyr::select(dat, -string_starts_with("p.value", x = colnames(dat)),
-                         -string_starts_with("std.p.value", x = colnames(dat)))
+    dat <- dplyr::select(
+      dat,
+      -string_starts_with("p.value", x = colnames(dat)),
+      -string_starts_with("std.p.value", x = colnames(dat))
+    )
   }
 
   if (show.df == FALSE) {
@@ -1379,13 +1386,13 @@ remove_unwanted <- function(dat,
   if (!is.null(terms)) {
     terms <- parse_terms(terms)
     keep_terms <- which(dat$term %in% terms)
-    dat <- dplyr::slice(dat, !! keep_terms)
+    dat <- dplyr::slice(dat, !!keep_terms)
   }
 
   if (!is.null(rm.terms)) {
     rm.terms <- parse_terms(rm.terms)
     keep_terms <- which(!(dat$term %in% rm.terms))
-    dat <- dplyr::slice(dat, !! keep_terms)
+    dat <- dplyr::slice(dat, !!keep_terms)
   }
 
   dat
@@ -1397,7 +1404,7 @@ prepare.labels <- function(x, grp, categorical, models) {
   # remove variable names from factor is ref levels are shown
   if (grp) {
     for (i in models) {
-      f <- names(which(sapply(insight::get_data(i), is.factor)))
+      f <- names(which(sapply(insight::get_data(i, verbose = FALSE), is.factor)))
       remove <- names(x) %in% f
       if (any(remove)) {
         x <- x[!remove]
@@ -1428,11 +1435,11 @@ format_p_values <- function(dat, p.style, digits.p, emph.p, p.threshold) {
     return(dat)
   }
 
-  dat <- dat %>%
+  dat <- dat |>
     dplyr::mutate(
-    p.stars = get_p_stars(.data$p.value, p.threshold),
-    p.sig = .data$p.value < .05
-  )
+      p.stars = get_p_stars(.data$p.value, p.threshold),
+      p.sig = .data$p.value < .05
+    )
 
   # scientific notation ----
 
@@ -1444,15 +1451,33 @@ format_p_values <- function(dat, p.style, digits.p, emph.p, p.threshold) {
 
   # emphasize p-values ----
 
-  if (emph.p && !all(dat$p.value == "NA")) dat$p.value[which(dat$p.sig)] <- sprintf("<strong>%s</strong>", dat$p.value[which(dat$p.sig)])
+  if (emph.p && !all(dat$p.value == "NA")) {
+    dat$p.value[which(dat$p.sig)] <- sprintf(
+      "<strong>%s</strong>",
+      dat$p.value[which(dat$p.sig)]
+    )
+  }
   dat <- dplyr::select(dat, -.data$p.sig)
 
   # indicate p <0.001 ----
 
   pv <- paste0("0.", paste(rep("0", digits.p), collapse = ""))
-  dat$p.value[dat$p.value == pv] <- paste("&lt;", format(10^(-digits.p), scientific = FALSE), sep = "")
+  dat$p.value[dat$p.value == pv] <- paste(
+    "&lt;",
+    format(10^(-digits.p), scientific = FALSE),
+    sep = ""
+  )
 
-  pv <- paste0("<strong>0.", paste(rep("0", digits.p), collapse = ""), "</strong>")
-  dat$p.value[dat$p.value == pv] <- paste("<strong>&lt;", format(10^(-digits.p), scientific = FALSE), "</strong>", sep = "")
+  pv <- paste0(
+    "<strong>0.",
+    paste(rep("0", digits.p), collapse = ""),
+    "</strong>"
+  )
+  dat$p.value[dat$p.value == pv] <- paste(
+    "<strong>&lt;",
+    format(10^(-digits.p), scientific = FALSE),
+    "</strong>",
+    sep = ""
+  )
   dat
 }
