@@ -66,8 +66,6 @@
 #' if (interactive()) {
 #'   tab_pca(efc[, start:end])
 #' }}
-#' @importFrom stats prcomp
-#' @importFrom performance cronbachs_alpha
 #' @export
 tab_pca <- function(data,
                     rotation = c("varimax", "quartimax", "promax", "oblimin", "simplimax", "cluster", "none"),
@@ -223,7 +221,7 @@ tab_pca <- function(data,
   if (!is.null(nmbr.fctr) && is.numeric(nmbr.fctr)) pcadata.kaiser <- nmbr.fctr
 
   if (pcadata.kaiser < 2) {
-    stop("Only one principal component extracted. Can't rotate loading matrices. You may use `nmbr.fctr` to extract more than one component.", call. = F)
+    stop("Only one principal component extracted. Can't rotate loading matrices. You may use `nmbr.fctr` to extract more than one component.", call. = FALSE)
   }
 
   rotation <- match.arg(rotation)
