@@ -89,9 +89,6 @@
 #'                           css.summary = "font-style:italic;"))
 #' }
 #' }
-#' @importFrom parameters kurtosis
-#' @importFrom datawizard skewness
-#' @importFrom sjmisc frq
 #' @export
 tab_stackfrq <- function(items,
                          weight.by = NULL,
@@ -148,7 +145,7 @@ tab_stackfrq <- function(items,
   if (is.null(value.labels)) {
     value.labels <- sjlabelled::get_labels(
       items[[1]],
-      attr.only = F,
+      attr.only = FALSE,
       values = "n",
       non.labelled = T
     )
@@ -183,7 +180,7 @@ tab_stackfrq <- function(items,
   # additional statistics required from psych-package?
   # ----------------------------
   if (show.skew) pstat_skewness <- datawizard::skewness(items)
-  if (show.kurtosis) pstat_kurtosis <- parameters::kurtosis(items)
+  if (show.kurtosis) pstat_kurtosis <- datawizard::kurtosis(items)
   if (is.null(weight.by)) {
     dummy <- sjmisc::frq(items, show.strings = TRUE, show.na = show.na)
   } else {
