@@ -99,8 +99,6 @@
 #'   )
 #' }
 #' }
-#' @importFrom stats ftable
-#' @importFrom sjstats crosstable_statistics table_values
 #' @export
 tab_xtab <- function(var.row,
                      var.col,
@@ -196,19 +194,19 @@ tab_xtab <- function(var.row,
   if (!is.null(value.labels)) {
     # need to be a list
     if (!is.list(value.labels)) {
-      warning("`valueLables` needs to be a `list`-object.", call. = F)
+      warning("`valueLables` needs to be a `list`-object.", call. = FALSE)
     } else {
       labels.var.row <- value.labels[[1]]
       labels.var.col <- value.labels[[2]]
     }
     # correct length of labels?
     if (length(labels.var.row) != length(mydat$labels.cnt)) {
-      warning("Length of `value.labels` does not match length of category values of `var.row`.", call. = F)
+      warning("Length of `value.labels` does not match length of category values of `var.row`.", call. = FALSE)
       labels.var.row <- mydat$labels.cnt
     }
     # correct length of labels?
     if (length(labels.var.col) != length(mydat$labels.grp)) {
-      warning("Length of `value.labels` does not match length of category values of `var.grp`.", call. = F)
+      warning("Length of `value.labels` does not match length of category values of `var.grp`.", call. = FALSE)
       labels.var.col <- mydat$labels.grp
     }
   }
@@ -466,9 +464,9 @@ tab_xtab <- function(var.row,
         xt_stat$method.html,
         xt_stat$estimate,
         pstring,
-        xt_stat$p.value,
-        sep = ""
-      )
+        xt_stat$p.value
+      ),
+      sep = ""
     )
     # close table row
     page.content <- paste(page.content, "\n  </tr>\n")
